.*Assembler messages:
.*16: Warning: SCFI ignores most user-specified CFI directives
.*19: Error: SCFI: unsupported stack manipulation pattern
.*75: Error: SCFI: forward pass failed for func 'drap_foo'
