[^:]*: Assembler messages:
[^:]*:21: Warning: float16 format cannot be set more than once, ignoring.
[^:]*:23: Error: cannot create floating-point number
[^:]*:24: Error: cannot create floating-point number
