[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.h,z1\.h ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z30\.h,z31\.h ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.h,z1\.h ?},z31\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.h ?- ?z3\.h ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z28\.h ?- ?z31\.h ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.h ?- ?z3\.h ?},{ ?z30\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.s,z1\.s ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z30\.s,z31\.s ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.s,z1\.s ?},z31\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.s ?- ?z3\.s ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z28\.s ?- ?z31\.s ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.s ?- ?z3\.s ?},{ ?z30\.h ?- ?z31\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.d,z1\.d ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z30\.d,z31\.d ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.d,z1\.d ?},z31\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.d ?- ?z3\.d ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z28\.d ?- ?z31\.d ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sunpk { ?z0\.d ?- ?z3\.d ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.h,z1\.h ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z30\.h,z31\.h ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.h,z1\.h ?},z31\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.h ?- ?z3\.h ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z28\.h ?- ?z31\.h ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.h ?- ?z3\.h ?},{ ?z30\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.s,z1\.s ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z30\.s,z31\.s ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.s,z1\.s ?},z31\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.s ?- ?z3\.s ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z28\.s ?- ?z31\.s ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.s ?- ?z3\.s ?},{ ?z30\.h ?- ?z31\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.d,z1\.d ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z30\.d,z31\.d ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.d,z1\.d ?},z31\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.d ?- ?z3\.d ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z28\.d ?- ?z31\.d ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uunpk { ?z0\.d ?- ?z3\.d ?},{ ?z30\.s ?- ?z31\.s ?}'
