[^ :]+: Assembler messages:
.*: Error: selected processor does not support `famax { ?z0.h ?- ?z1.h ?},{ ?z0.h ?- ?z1.h ?},{ ?z0.h ?- ?z1.h ?}'
.*: Error: selected processor does not support `famax { ?z30.h ?- ?z31.h ?},{ ?z30.h ?- ?z31.h ?},{ ?z0.h ?- ?z1.h ?}'
.*: Error: selected processor does not support `famax { ?z0.h ?- ?z1.h ?},{ ?z0.h ?- ?z1.h ?},{ ?z30.h ?- ?z31.h ?}'
.*: Error: selected processor does not support `famax { ?z18.h ?- ?z19.h ?},{ ?z18.h ?- ?z19.h ?},{ ?z26.h ?- ?z27.h ?}'
.*: Error: selected processor does not support `famax { ?z0.s ?- ?z1.s ?},{ ?z0.s ?- ?z1.s ?},{ ?z0.s ?- ?z1.s ?}'
.*: Error: selected processor does not support `famax { ?z30.s ?- ?z31.s ?},{ ?z30.s ?- ?z31.s ?},{ ?z0.s ?- ?z1.s ?}'
.*: Error: selected processor does not support `famax { ?z0.s ?- ?z1.s ?},{ ?z0.s ?- ?z1.s ?},{ ?z30.s ?- ?z31.s ?}'
.*: Error: selected processor does not support `famax { ?z4.s ?- ?z5.s ?},{ ?z4.s ?- ?z5.s ?},{ ?z10.s ?- ?z11.s ?}'
.*: Error: selected processor does not support `famax { ?z0.d ?- ?z1.d ?},{ ?z0.d ?- ?z1.d ?},{ ?z0.d ?- ?z1.d ?}'
.*: Error: selected processor does not support `famax { ?z30.d ?- ?z31.d ?},{ ?z30.d ?- ?z31.d ?},{ ?z0.d ?- ?z1.d ?}'
.*: Error: selected processor does not support `famax { ?z0.d ?- ?z1.d ?},{ ?z0.d ?- ?z1.d ?},{ ?z30.d ?- ?z31.d ?}'
.*: Error: selected processor does not support `famax { ?z28.d ?- ?z29.d ?},{ ?z28.d ?- ?z29.d ?},{ ?z8.d ?- ?z9.d ?}'
.*: Error: selected processor does not support `famax { ?z0.h ?- ?z3.h ?},{ ?z0.h ?- ?z3.h ?},{ ?z0.h ?- ?z3.h ?}'
.*: Error: selected processor does not support `famax { ?z28.h ?- ?z31.h ?},{ ?z28.h ?- ?z31.h ?},{ ?z0.h ?- ?z3.h ?}'
.*: Error: selected processor does not support `famax { ?z0.h ?- ?z3.h ?},{ ?z0.h ?- ?z3.h ?},{ ?z28.h ?- ?z31.h ?}'
.*: Error: selected processor does not support `famax { ?z16.h ?- ?z19.h ?},{ ?z16.h ?- ?z19.h ?},{ ?z20.h ?- ?z23.h ?}'
.*: Error: selected processor does not support `famax { ?z0.s ?- ?z3.s ?},{ ?z0.s ?- ?z3.s ?},{ ?z0.s ?- ?z3.s ?}'
.*: Error: selected processor does not support `famax { ?z28.s ?- ?z31.s ?},{ ?z28.s ?- ?z31.s ?},{ ?z0.s ?- ?z3.s ?}'
.*: Error: selected processor does not support `famax { ?z0.s ?- ?z3.s ?},{ ?z0.s ?- ?z3.s ?},{ ?z28.s ?- ?z31.s ?}'
.*: Error: selected processor does not support `famax { ?z24.s ?- ?z27.s ?},{ ?z24.s ?- ?z27.s ?},{ ?z4.s ?- ?z7.s ?}'
.*: Error: selected processor does not support `famax { ?z0.d ?- ?z3.d ?},{ ?z0.d ?- ?z3.d ?},{ ?z0.d ?- ?z3.d ?}'
.*: Error: selected processor does not support `famax { ?z28.d ?- ?z31.d ?},{ ?z28.d ?- ?z31.d ?},{ ?z0.d ?- ?z3.d ?}'
.*: Error: selected processor does not support `famax { ?z0.d ?- ?z3.d ?},{ ?z0.d ?- ?z3.d ?},{ ?z28.d ?- ?z31.d ?}'
.*: Error: selected processor does not support `famax { ?z12.d ?- ?z15.d ?},{ ?z12.d ?- ?z15.d ?},{ ?z8.d ?- ?z11.d ?}'
.*: Error: selected processor does not support `famin { ?z0.h ?- ?z1.h ?},{ ?z0.h ?- ?z1.h ?},{ ?z0.h ?- ?z1.h ?}'
.*: Error: selected processor does not support `famin { ?z30.h ?- ?z31.h ?},{ ?z30.h ?- ?z31.h ?},{ ?z0.h ?- ?z1.h ?}'
.*: Error: selected processor does not support `famin { ?z0.h ?- ?z1.h ?},{ ?z0.h ?- ?z1.h ?},{ ?z30.h ?- ?z31.h ?}'
.*: Error: selected processor does not support `famin { ?z18.h ?- ?z19.h ?},{ ?z18.h ?- ?z19.h ?},{ ?z26.h ?- ?z27.h ?}'
.*: Error: selected processor does not support `famin { ?z0.s ?- ?z1.s ?},{ ?z0.s ?- ?z1.s ?},{ ?z0.s ?- ?z1.s ?}'
.*: Error: selected processor does not support `famin { ?z30.s ?- ?z31.s ?},{ ?z30.s ?- ?z31.s ?},{ ?z0.s ?- ?z1.s ?}'
.*: Error: selected processor does not support `famin { ?z0.s ?- ?z1.s ?},{ ?z0.s ?- ?z1.s ?},{ ?z30.s ?- ?z31.s ?}'
.*: Error: selected processor does not support `famin { ?z4.s ?- ?z5.s ?},{ ?z4.s ?- ?z5.s ?},{ ?z10.s ?- ?z11.s ?}'
.*: Error: selected processor does not support `famin { ?z0.d ?- ?z1.d ?},{ ?z0.d ?- ?z1.d ?},{ ?z0.d ?- ?z1.d ?}'
.*: Error: selected processor does not support `famin { ?z30.d ?- ?z31.d ?},{ ?z30.d ?- ?z31.d ?},{ ?z0.d ?- ?z1.d ?}'
.*: Error: selected processor does not support `famin { ?z0.d ?- ?z1.d ?},{ ?z0.d ?- ?z1.d ?},{ ?z30.d ?- ?z31.d ?}'
.*: Error: selected processor does not support `famin { ?z28.d ?- ?z29.d ?},{ ?z28.d ?- ?z29.d ?},{ ?z8.d ?- ?z9.d ?}'
.*: Error: selected processor does not support `famin { ?z0.h ?- ?z3.h ?},{ ?z0.h ?- ?z3.h ?},{ ?z0.h ?- ?z3.h ?}'
.*: Error: selected processor does not support `famin { ?z28.h ?- ?z31.h ?},{ ?z28.h ?- ?z31.h ?},{ ?z0.h ?- ?z3.h ?}'
.*: Error: selected processor does not support `famin { ?z0.h ?- ?z3.h ?},{ ?z0.h ?- ?z3.h ?},{ ?z28.h ?- ?z31.h ?}'
.*: Error: selected processor does not support `famin { ?z16.h ?- ?z19.h ?},{ ?z16.h ?- ?z19.h ?},{ ?z20.h ?- ?z23.h ?}'
.*: Error: selected processor does not support `famin { ?z0.s ?- ?z3.s ?},{ ?z0.s ?- ?z3.s ?},{ ?z0.s ?- ?z3.s ?}'
.*: Error: selected processor does not support `famin { ?z28.s ?- ?z31.s ?},{ ?z28.s ?- ?z31.s ?},{ ?z0.s ?- ?z3.s ?}'
.*: Error: selected processor does not support `famin { ?z0.s ?- ?z3.s ?},{ ?z0.s ?- ?z3.s ?},{ ?z28.s ?- ?z31.s ?}'
.*: Error: selected processor does not support `famin { ?z24.s ?- ?z27.s ?},{ ?z24.s ?- ?z27.s ?},{ ?z4.s ?- ?z7.s ?}'
.*: Error: selected processor does not support `famin { ?z0.d ?- ?z3.d ?},{ ?z0.d ?- ?z3.d ?},{ ?z0.d ?- ?z3.d ?}'
.*: Error: selected processor does not support `famin { ?z28.d ?- ?z31.d ?},{ ?z28.d ?- ?z31.d ?},{ ?z0.d ?- ?z3.d ?}'
.*: Error: selected processor does not support `famin { ?z0.d ?- ?z3.d ?},{ ?z0.d ?- ?z3.d ?},{ ?z28.d ?- ?z31.d ?}'
.*: Error: selected processor does not support `famin { ?z12.d ?- ?z15.d ?},{ ?z12.d ?- ?z15.d ?},{ ?z8.d ?- ?z11.d ?}'
