[^:]*: Assembler messages:
[^:]*:1: Error: file was compiled for the 430 ISA but the 430X ISA is selected
[^:]*:2: Error: file was compiled for the small memory model, but the large memory model is selected
[^:]*:3: Error: file was compiled for the small memory model, but the large memory model is selected
