[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w10,3\],{ ?z10\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,1\],{ ?z12\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?},Z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?},Z0\.S'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z31\.s,z0\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z31\.s ?- ?z0\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},z15\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w9,5\],{ ?z9\.s ?- ?z10\.s ?},z6\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?},Z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?},Z0\.S'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z31\.s,z0\.s,z1\.s,z2\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z31\.s ?- ?z2\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},z15\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,2\],{ ?z23\.s ?- ?z26\.s ?},z13\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?},{ ?Z0\.s ?- ?Z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?},{ ?Z0\.S ?- ?Z1\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w10,1\],{ ?z22\.s ?- ?z23\.s ?},{ ?z18\.s ?- ?z19\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?},{ ?Z0\.s ?- ?Z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?},{ ?Z0\.S ?- ?Z3\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add za\.s\[w11,3\],{ ?z16\.s ?- ?z19\.s ?},{ ?z24\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z30\.b ?- ?z31\.b ?},{ ?z30\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z14\.b ?- ?z15\.b ?},{ ?z14\.b ?- ?z15\.b ?},z5\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z30\.h ?- ?z31\.h ?},{ ?z30\.h ?- ?z31\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?},z15\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z20\.h ?- ?z21\.h ?},{ ?z20\.h ?- ?z21\.h ?},z11\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z30\.s ?- ?z31\.s ?},{ ?z30\.s ?- ?z31\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?},z15\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z2\.s ?- ?z3\.s ?},{ ?z2\.s ?- ?z3\.s ?},z9\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.d ?- ?z1\.d ?},{ ?z0\.d ?- ?z1\.d ?},z0\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z30\.d ?- ?z31\.d ?},{ ?z30\.d ?- ?z31\.d ?},z0\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.d ?- ?z1\.d ?},{ ?z0\.d ?- ?z1\.d ?},z15\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z28\.d ?- ?z29\.d ?},{ ?z28\.d ?- ?z29\.d ?},z1\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z28\.b ?- ?z31\.b ?},{ ?z28\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z24\.b ?- ?z27\.b ?},{ ?z24\.b ?- ?z27\.b ?},z5\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z28\.h ?- ?z31\.h ?},{ ?z28\.h ?- ?z31\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?},z15\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z20\.h ?- ?z23\.h ?},{ ?z20\.h ?- ?z23\.h ?},z11\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z28\.s ?- ?z31\.s ?},{ ?z28\.s ?- ?z31\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?},z15\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z4\.s ?- ?z7\.s ?},{ ?z4\.s ?- ?z7\.s ?},z9\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.d ?- ?z3\.d ?},{ ?z0\.d ?- ?z3\.d ?},z0\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z28\.d ?- ?z31\.d ?},{ ?z28\.d ?- ?z31\.d ?},z0\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z0\.d ?- ?z3\.d ?},{ ?z0\.d ?- ?z3\.d ?},z15\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `add { ?z16\.d ?- ?z19\.d ?},{ ?z16\.d ?- ?z19\.d ?},z3\.d'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w10,3\],{ ?z10\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,1\],{ ?z12\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?},Z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?},Z0\.S'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z31\.s,z0\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z31\.s ?- ?z0\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},z15\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w9,5\],{ ?z9\.s ?- ?z10\.s ?},z6\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?},Z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?},Z0\.S'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z31\.s,z0\.s,z1\.s,z2\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z31\.s ?- ?z2\.s ?},z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},z15\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,2\],{ ?z23\.s ?- ?z26\.s ?},z13\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?},{ ?Z0\.s ?- ?Z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?},{ ?Z0\.S ?- ?Z1\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w10,1\],{ ?z22\.s ?- ?z23\.s ?},{ ?z18\.s ?- ?z19\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?},{ ?Z0\.s ?- ?Z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?},{ ?Z0\.S ?- ?Z3\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sub za\.s\[w11,3\],{ ?z16\.s ?- ?z19\.s ?},{ ?z24\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w10,3\],{ ?z10\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.s\[w11,1\],{ ?z12\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,0,vgx2\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.s\[W8,0,VGx2\],{ ?Z0\.s ?- ?Z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.S\[W8,0,VGX2\],{ ?Z0\.S ?- ?Z1\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w11,0\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,7\],{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,0\],{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w10,3\],{ ?z10\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,0,vgx4\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.s\[W8,0,VGx4\],{ ?Z0\.s ?- ?Z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.S\[W8,0,VGX4\],{ ?Z0\.S ?- ?Z3\.S ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w11,0\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,7\],{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w8,0\],{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.s\[w11,1\],{ ?z12\.s ?- ?z15\.s ?}'
