#as: -mabi=lp64
#objdump: -dr
# This test is only valid on ELF based ports.
#notarget: *-*-*coff *-*-pe *-*-wince *-*-*aout* *-*-netbsd

.*:     file format .*

Disassembly of section \.text:

0000000000000000 <.*>:
   0:	f280001c 	movk	x28, #0x0
			0: R_AARCH64_TLSIE_MOVW_GOTTPREL_G0_NC	x
