#nm: --extern-only --numeric-sort
#name: quoted label name followed by whitespace
# No quoted strings handling (TC_STRING_ESCAPES set to 0):
#notarget: powerpc*-*-aix* powerpc*-*-beos* powerpc-*-macos* rs6000-*-*
# Certain LABELS_WITHOUT_COLONS targets:
#notarget: mmix-*-* tic54*-*-* z80-*-*

#...
0+00 D blank-after
