.*: Assembler messages:
.*:9: Error: JALX to a symbol in the same ISA mode
.*:15: Error: JALX to a symbol in the same ISA mode
.*:17: Error: jump to misaligned address \(0x11a1\)
.*:19: Error: jump to misaligned address \(0x11a1\)
.*:21: Error: JALX to a symbol in the same ISA mode
.*:23: Error: jump to misaligned address \(0x11a2\)
.*:25: Error: jump to misaligned address \(0x11a2\)
.*:27: Error: JALX to a symbol in the same ISA mode
.*:29: Error: jump to misaligned address \(0x11a3\)
.*:31: Error: jump to misaligned address \(0x11a3\)
.*:33: Error: JALX to a symbol in the same ISA mode
.*:39: Error: JALX to a symbol in the same ISA mode
.*:41: Error: jump to misaligned address \(0x11a5\)
.*:43: Error: jump to misaligned address \(0x11a5\)
.*:45: Error: JALX to a symbol in the same ISA mode
.*:47: Error: jump to misaligned address \(0x11a6\)
.*:49: Error: jump to misaligned address \(0x11a6\)
.*:51: Error: JALX to a symbol in the same ISA mode
.*:53: Error: jump to misaligned address \(0x11a7\)
.*:55: Error: jump to misaligned address \(0x11a7\)
.*:57: Error: JALX to a symbol in the same ISA mode
.*:67: Error: jump to a symbol in another ISA mode
.*:69: Error: jump to misaligned address \(0x11b2\)
.*:71: Error: jump to misaligned address \(0x11b2\)
.*:73: Error: jump to a symbol in another ISA mode
.*:79: Error: jump to a symbol in another ISA mode
.*:81: Error: jump to misaligned address \(0x11b5\)
.*:83: Error: jump to misaligned address \(0x11b5\)
.*:85: Error: jump to a symbol in another ISA mode
.*:87: Error: jump to misaligned address \(0x11b6\)
.*:89: Error: jump to misaligned address \(0x11b6\)
.*:91: Error: jump to a symbol in another ISA mode
.*:93: Error: jump to misaligned address \(0x11b7\)
.*:95: Error: jump to misaligned address \(0x11b7\)
.*:97: Error: jump to a symbol in another ISA mode
.*:103: Error: jump to a symbol in another ISA mode
