	.text
	.am33
	mov 0x7ffefdfc,r2
	movu 0x7ffefdfc,r2
	add 0x7ffefdfc,r2
	addc 0x7ffefdfc,r2
	sub 0x7ffefdfc,r2
	subc 0x7ffefdfc,r2
	cmp 0x7ffefdfc,r2
	mov 0x7ffefdfc,xr2
	and 0x7ffefdfc,r2
	or 0x7ffefdfc,r2
	xor 0x7ffefdfc,r2
	asr 0x7ffefdfc,r2
	lsr 0x7ffefdfc,r2
	asl 0x7ffefdfc,r2
	mul 0x7ffefdfc,r2
	mulu 0x7ffefdfc,r2
	btst 0x7ffefdfc,r2
	mov (0x7ffefdfc,r1),r2
	mov r2,(0x7ffefdfc,r1)
	movbu (0x7ffefdfc,r1),r2
	movbu r2,(0x7ffefdfc,r1)
	movhu (0x7ffefdfc,r1),r2
	movhu r2,(0x7ffefdfc,r1)
	mov (0x7ffefdfc,sp),r2
	mov r2,(0x7ffefdfc,sp)
	movbu (0x7ffefdfc,sp),r2
	movbu r2,(0x7ffefdfc,sp)
	movhu (0x7ffefdfc,sp),r2
	movhu r2,(0x7ffefdfc,sp)
	mac 0x7ffefdfc,r2
	macu 0x7ffefdfc,r2
	macb 0x7ffefdfc,r2
	macbu 0x7ffefdfc,r2
	mach 0x7ffefdfc,r2
	machu 0x7ffefdfc,r2
	dmach 0x7ffefdfc,r2
	dmachu 0x7ffefdfc,r2
	dmulh 0x7ffefdfc,r2
	dmulhu 0x7ffefdfc,r2
	mov (0x7ffefdfc),r2
	mov r2,(0x7ffefdfc)
	movbu (0x7ffefdfc),r2
	movbu r2,(0x7ffefdfc)
	movhu (0x7ffefdfc),r2
	movhu r2,(0x7ffefdfc)
	mul d0,d1,a0,a1
	mulu d0,d1,a0,a1
	mov (r1+,0x7ffefdfc),r2
	mov r1,(r2+,0x7ffefdfc)
	movhu (r1+,0x7ffefdfc),r2
	movhu r1,(r2+,0x7ffefdfc)
	mov (-16,sp),r2
	mov r2,(-16,sp)
	movbu (-16,sp),r2
	movbu r2,(-16,sp)
	movhu (-16,sp),r2
	movhu r2,(-16,sp)
	mov (-1024,sp),r2
	mov r2,(-1024,sp)
	movbu (-1024,sp),r2
	movbu r2,(-1024,sp)
	movhu (-1024,sp),r2
	movhu r2,(-1024,sp)
