[^:]*: Assembler messages:
[^:]*:3: Error: bad type in SIMD instruction -- `vqmovnt.s8 q0,q1'
[^:]*:4: Error: bad type in SIMD instruction -- `vqmovnt.s64 q0,q1'
[^:]*:5: Error: bad type in SIMD instruction -- `vqmovnt.i16 q0,q1'
[^:]*:6: Error: bad type in SIMD instruction -- `vqmovnb.u8 q0,q1'
[^:]*:7: Error: bad type in SIMD instruction -- `vqmovnb.u64 q0,q1'
[^:]*:8: Error: bad type in SIMD instruction -- `vqmovnb.i16 q0,q1'
[^:]*:9: Error: bad type in SIMD instruction -- `vqmovunt.s8 q0,q1'
[^:]*:10: Error: bad type in SIMD instruction -- `vqmovunt.s64 q0,q1'
[^:]*:11: Error: bad type in SIMD instruction -- `vqmovunt.i16 q0,q1'
[^:]*:12: Error: bad type in SIMD instruction -- `vqmovunb.s8 q0,q1'
[^:]*:13: Error: bad type in SIMD instruction -- `vqmovunb.s64 q0,q1'
[^:]*:14: Error: bad type in SIMD instruction -- `vqmovunb.i16 q0,q1'
[^:]*:15: Error: bad type in SIMD instruction -- `vqmovunt.u16 q0,q1'
[^:]*:16: Error: bad type in SIMD instruction -- `vqmovunt.u32 q0,q1'
[^:]*:17: Error: bad type in SIMD instruction -- `vqmovunb.u16 q0,q1'
[^:]*:18: Error: bad type in SIMD instruction -- `vqmovunb.u32 q0,q1'
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:31: Error: syntax error -- `vqmovnteq.s16 q0,q1'
[^:]*:32: Error: syntax error -- `vqmovnteq.s16 q0,q1'
[^:]*:34: Error: syntax error -- `vqmovnteq.s16 q0,q1'
[^:]*:35: Error: vector predicated instruction should be in VPT/VPST block -- `vqmovntt.s16 q0,q1'
[^:]*:37: Error: instruction missing MVE vector predication code -- `vqmovnt.s16 q0,q1'
[^:]*:39: Error: syntax error -- `vqmovnbeq.s16 q0,q1'
[^:]*:40: Error: syntax error -- `vqmovnbeq.s16 q0,q1'
[^:]*:42: Error: syntax error -- `vqmovnbeq.s16 q0,q1'
[^:]*:43: Error: vector predicated instruction should be in VPT/VPST block -- `vqmovnbt.s16 q0,q1'
[^:]*:45: Error: instruction missing MVE vector predication code -- `vqmovnb.s16 q0,q1'
[^:]*:47: Error: syntax error -- `vqmovunteq.s16 q0,q1'
[^:]*:48: Error: syntax error -- `vqmovunteq.s16 q0,q1'
[^:]*:50: Error: syntax error -- `vqmovunteq.s16 q0,q1'
[^:]*:51: Error: vector predicated instruction should be in VPT/VPST block -- `vqmovuntt.s16 q0,q1'
[^:]*:53: Error: instruction missing MVE vector predication code -- `vqmovunt.s16 q0,q1'
[^:]*:55: Error: syntax error -- `vqmovunbeq.s16 q0,q1'
[^:]*:56: Error: syntax error -- `vqmovunbeq.s16 q0,q1'
[^:]*:58: Error: syntax error -- `vqmovunbeq.s16 q0,q1'
[^:]*:59: Error: vector predicated instruction should be in VPT/VPST block -- `vqmovunbt.s16 q0,q1'
[^:]*:61: Error: instruction missing MVE vector predication code -- `vqmovunb.s16 q0,q1'
