#readelf: -A
#name: C6X compatibility attribute, directives 2
#as:
#source: attr-compatibility-directive-2.s

Attribute Section: c6xabi
File Attributes
  Tag_ISA: C674x
  Tag_ABI_compatibility: flag = 1, vendor = gnu
