	.text
	.org 0
;;;  bit manipulation
	bit 0,a
	bit 0,b
	bit 0,c
	bit 0,d
	bit 0,e
	bit 0,h
	bit 0,l
	bit 0,(hl)
	bit 0,(ix+5)
	bit 0,(iy+5)
	bit 1,a
	bit 1,b
	bit 1,c
	bit 1,d
	bit 1,e
	bit 1,h
	bit 1,l
	bit 1,(hl)
	bit 1,(ix+5)
	bit 1,(iy+5)
	bit 2,a
	bit 2,b
	bit 2,c
	bit 2,d
	bit 2,e
	bit 2,h
	bit 2,l
	bit 2,(hl)
	bit 2,(ix+5)
	bit 2,(iy+5)
	bit 3,a
	bit 3,b
	bit 3,c
	bit 3,d
	bit 3,e
	bit 3,h
	bit 3,l
	bit 3,(hl)
	bit 3,(ix+5)
	bit 3,(iy+5)
	bit 4,a
	bit 4,b
	bit 4,c
	bit 4,d
	bit 4,e
	bit 4,h
	bit 4,l
	bit 4,(hl)
	bit 4,(ix+5)
	bit 4,(iy+5)
	bit 5,a
	bit 5,b
	bit 5,c
	bit 5,d
	bit 5,e
	bit 5,h
	bit 5,l
	bit 5,(hl)
	bit 5,(ix+5)
	bit 5,(iy+5)
	bit 6,a
	bit 6,b
	bit 6,c
	bit 6,d
	bit 6,e
	bit 6,h
	bit 6,l
	bit 6,(hl)
	bit 6,(ix+5)
	bit 6,(iy+5)
	bit 7,a
	bit 7,b
	bit 7,c
	bit 7,d
	bit 7,e
	bit 7,h
	bit 7,l
	bit 7,(hl)
	bit 7,(ix+5)
	bit 7,(iy+5)

	res 0,a
	res 0,b
	res 0,c
	res 0,d
	res 0,e
	res 0,h
	res 0,l
	res 0,(hl)
	res 0,(ix+5)
	res 0,(iy+5)
	res 1,a
	res 1,b
	res 1,c
	res 1,d
	res 1,e
	res 1,h
	res 1,l
	res 1,(hl)
	res 1,(ix+5)
	res 1,(iy+5)
	res 2,a
	res 2,b
	res 2,c
	res 2,d
	res 2,e
	res 2,h
	res 2,l
	res 2,(hl)
	res 2,(ix+5)
	res 2,(iy+5)
	res 3,a
	res 3,b
	res 3,c
	res 3,d
	res 3,e
	res 3,h
	res 3,l
	res 3,(hl)
	res 3,(ix+5)
	res 3,(iy+5)
	res 4,a
	res 4,b
	res 4,c
	res 4,d
	res 4,e
	res 4,h
	res 4,l
	res 4,(hl)
	res 4,(ix+5)
	res 4,(iy+5)
	res 5,a
	res 5,b
	res 5,c
	res 5,d
	res 5,e
	res 5,h
	res 5,l
	res 5,(hl)
	res 5,(ix+5)
	res 5,(iy+5)
	res 6,a
	res 6,b
	res 6,c
	res 6,d
	res 6,e
	res 6,h
	res 6,l
	res 6,(hl)
	res 6,(ix+5)
	res 6,(iy+5)
	res 7,a
	res 7,b
	res 7,c
	res 7,d
	res 7,e
	res 7,h
	res 7,l
	res 7,(hl)
	res 7,(ix+5)
	res 7,(iy+5)

	set 0,a
	set 0,b
	set 0,c
	set 0,d
	set 0,e
	set 0,h
	set 0,l
	set 0,(hl)
	set 0,(ix+5)
	set 0,(iy+5)
	set 1,a
	set 1,b
	set 1,c
	set 1,d
	set 1,e
	set 1,h
	set 1,l
	set 1,(hl)
	set 1,(ix+5)
	set 1,(iy+5)
	set 2,a
	set 2,b
	set 2,c
	set 2,d
	set 2,e
	set 2,h
	set 2,l
	set 2,(hl)
	set 2,(ix+5)
	set 2,(iy+5)
	set 3,a
	set 3,b
	set 3,c
	set 3,d
	set 3,e
	set 3,h
	set 3,l
	set 3,(hl)
	set 3,(ix+5)
	set 3,(iy+5)
	set 4,a
	set 4,b
	set 4,c
	set 4,d
	set 4,e
	set 4,h
	set 4,l
	set 4,(hl)
	set 4,(ix+5)
	set 4,(iy+5)
	set 5,a
	set 5,b
	set 5,c
	set 5,d
	set 5,e
	set 5,h
	set 5,l
	set 5,(hl)
	set 5,(ix+5)
	set 5,(iy+5)
	set 6,a
	set 6,b
	set 6,c
	set 6,d
	set 6,e
	set 6,h
	set 6,l
	set 6,(hl)
	set 6,(ix+5)
	set 6,(iy+5)
	set 7,a
	set 7,b
	set 7,c
	set 7,d
	set 7,e
	set 7,h
	set 7,l
	set 7,(hl)
	set 7,(ix+5)
	set 7,(iy+5)
