        neg.l [0x123456]
        neg.b [4,x]
        neg.w d2
        neg.b [d0, y]
        neg.b [12,s]
        neg.b (3,s)
        neg.b (-123,s)
        neg.l (0x123abc,p)
        neg.w (x-)
        neg.w (y-)
        neg.b (x+)
        neg.b (y+)
        neg.b (s+)
        neg.l (+x)
        neg.w (+y)
        neg.l (-x)
        neg.w (-y)
        neg.b (-s)
        neg.l (d1, x)
        neg.l (d2, y)
        neg.l (d3, s)
