.*: Assembler messages:
.*:12: Error: operand 3 out of range `ext \$4,\$5,-1,1'
.*:15: Error: operand 3 out of range `ext \$4,\$5,32,1'
.*:18: Error: operand 4 out of range `ext \$4,\$5,0,0'
.*:21: Error: operand 4 out of range `ext \$4,\$5,0,33'
.*:24: Error: operand 4 out of range `ext \$4,\$5,0,0'
.*:27: Error: operand 4 out of range `ext \$4,\$5,31,2'
.*:30: Error: operand 3 out of range `ins \$4,\$5,-1,1'
.*:33: Error: operand 3 out of range `ins \$4,\$5,32,1'
.*:36: Error: operand 4 out of range `ins \$4,\$5,0,0'
.*:39: Error: operand 4 out of range `ins \$4,\$5,0,33'
.*:42: Error: operand 4 out of range `ins \$4,\$5,0,0'
.*:45: Error: operand 4 out of range `ins \$4,\$5,31,2'
.*:54: Warning: float register should be even, was 1
.*:57: Warning: float register should be even, was 1
