[^:]*: Assembler messages:
[^:]*:26: Error: operand mismatch -- `cas w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `cas w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casa w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casa w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casl w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casl w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casal w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casal w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casb w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casb w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `cash w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `cash w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casab w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casab w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `caslb w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `caslb w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casalb w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casalb w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casah w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casah w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `caslh w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `caslh w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `casalh w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `casalh w2,w3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `cas w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `cas x2,x3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `casa w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `casa x2,x3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `casl w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `casl x2,x3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `casal w0,x1,\[x2\]'
[^:]*:68: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `casal x2,x3,\[w4\]'
[^:]*:68: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swp w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swp w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpa w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpa w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpl w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpl w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpal w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpal w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpb w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpb w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swph w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swph w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpab w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpab w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swplb w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swplb w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpalb w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpalb w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpah w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpah w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swplh w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swplh w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `swpalh w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `swpalh w2,w3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `swp w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `swp x2,x3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `swpa w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `swpa x2,x3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `swpl w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `swpl x2,x3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `swpal w0,x1,\[x2\]'
[^:]*:69: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `swpal x2,x3,\[w4\]'
[^:]*:69: *Info: macro .*
[^:]*:47: Error: reg pair must start from even reg at operand 1 -- `casp w1,w1,w2,w3,\[x5\]'
[^:]*:70: *Info: macro .*
[^:]*:48: Error: reg pair must be contiguous at operand 2 -- `casp w4,w4,w6,w7,\[sp\]'
[^:]*:70: *Info: macro .*
[^:]*:49: Error: operand mismatch -- `casp w0,x1,x2,x3,\[x2\]'
[^:]*:70: *Info: macro .*
[^:]*:50: Error: expected a 64-bit base register at operand 5 -- `casp x4,x5,x6,x7,\[w8\]'
[^:]*:70: *Info: macro .*
[^:]*:47: Error: reg pair must start from even reg at operand 1 -- `caspa w1,w1,w2,w3,\[x5\]'
[^:]*:70: *Info: macro .*
[^:]*:48: Error: reg pair must be contiguous at operand 2 -- `caspa w4,w4,w6,w7,\[sp\]'
[^:]*:70: *Info: macro .*
[^:]*:49: Error: operand mismatch -- `caspa w0,x1,x2,x3,\[x2\]'
[^:]*:70: *Info: macro .*
[^:]*:50: Error: expected a 64-bit base register at operand 5 -- `caspa x4,x5,x6,x7,\[w8\]'
[^:]*:70: *Info: macro .*
[^:]*:47: Error: reg pair must start from even reg at operand 1 -- `caspl w1,w1,w2,w3,\[x5\]'
[^:]*:70: *Info: macro .*
[^:]*:48: Error: reg pair must be contiguous at operand 2 -- `caspl w4,w4,w6,w7,\[sp\]'
[^:]*:70: *Info: macro .*
[^:]*:49: Error: operand mismatch -- `caspl w0,x1,x2,x3,\[x2\]'
[^:]*:70: *Info: macro .*
[^:]*:50: Error: expected a 64-bit base register at operand 5 -- `caspl x4,x5,x6,x7,\[w8\]'
[^:]*:70: *Info: macro .*
[^:]*:47: Error: reg pair must start from even reg at operand 1 -- `caspal w1,w1,w2,w3,\[x5\]'
[^:]*:70: *Info: macro .*
[^:]*:48: Error: reg pair must be contiguous at operand 2 -- `caspal w4,w4,w6,w7,\[sp\]'
[^:]*:70: *Info: macro .*
[^:]*:49: Error: operand mismatch -- `caspal w0,x1,x2,x3,\[x2\]'
[^:]*:70: *Info: macro .*
[^:]*:50: Error: expected a 64-bit base register at operand 5 -- `caspal x4,x5,x6,x7,\[w8\]'
[^:]*:70: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldadd w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldadd w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldadda w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldadda w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddal w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddalb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddalb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldaddalh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldaddalh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldadd w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldadd x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldadda w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldadda x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldaddl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldaddl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldaddal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldaddal x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclr w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclr w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclra w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclra w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclral w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclral w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclralb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclralb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclrlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclrlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldclralh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldclralh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldclr w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldclr x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldclra w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldclra x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldclrl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldclrl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldclral w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldclral x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeor w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeor w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeora w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeora w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeoral w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeoral w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeoralb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeoralb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeorlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeorlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldeoralh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldeoralh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldeor w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldeor x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldeora w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldeora x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldeorl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldeorl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldeoral w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldeoral x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldset w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldset w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldseta w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldseta w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetal w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldseth w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldseth w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetalb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetalb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsetalh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsetalh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldset w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldset x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldseta w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldseta x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsetl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsetl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsetal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsetal x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmax w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmax w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxa w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxa w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxal w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxalb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxalb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmaxalh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmaxalh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsmax w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsmax x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsmaxa w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsmaxa x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsmaxl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsmaxl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsmaxal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsmaxal x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmin w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmin w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsmina w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsmina w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminal w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminalb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminalb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldsminalh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldsminalh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsmin w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsmin x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsmina w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsmina x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsminl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsminl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldsminal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldsminal x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumax w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumax w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxa w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxa w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxal w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxalb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxalb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumaxalh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumaxalh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldumax w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldumax x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldumaxa w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldumaxa x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldumaxl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldumaxl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldumaxal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldumaxal x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumin w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumin w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `ldumina w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `ldumina w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminl w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminal w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminab w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminab w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminlb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminlb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminalb w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminalb w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminah w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminah w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminlh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminlh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:26: Error: operand mismatch -- `lduminalh w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:27: Error: expected a 64-bit base register at operand 3 -- `lduminalh w2,w3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldumin w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldumin x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `ldumina w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `ldumina x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `lduminl w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `lduminl x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:30: Error: operand mismatch -- `lduminal w0,x1,\[x2\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:31: Error: expected a 64-bit base register at operand 3 -- `lduminal x2,x3,\[w4\]'
[^:]*:56: *Info: macro .*
[^:]*:71: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stadd w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `staddl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `staddb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `staddb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `staddh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `staddh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `staddlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `staddlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `staddlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `staddlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stadd x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `staddl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stclr w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stclrl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stclrb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stclrb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stclrh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stclrh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stclrlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stclrlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stclrlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stclrlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stclr x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stclrl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `steor w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `steorl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `steorb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `steorb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `steorh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `steorh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `steorlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `steorlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `steorlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `steorlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `steor x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `steorl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stset w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsetl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsetb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsetb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stseth x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stseth w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsetlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsetlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsetlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsetlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stset x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stsetl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmax w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmaxl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsmaxb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmaxb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsmaxh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmaxh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsmaxlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmaxlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsmaxlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmaxlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stsmax x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stsmaxl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsmin w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsminl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsminb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsminb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsminh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsminh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsminlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsminlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stsminlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stsminlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stsmin x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stsminl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumax w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumaxl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stumaxb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumaxb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stumaxh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumaxh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stumaxlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumaxlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stumaxlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumaxlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stumax x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stumaxl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stumin w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stuminl w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stuminb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stuminb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stuminh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stuminh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stuminlb x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stuminlb w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:37: Error: operand mismatch -- `stuminlh x0,\[x2\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:38: Error: expected a 64-bit base register at operand 2 -- `stuminlh w2,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stumin x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
[^:]*:41: Error: expected a 64-bit base register at operand 2 -- `stuminl x0,\[w3\]'
[^:]*:62: *Info: macro .*
[^:]*:72: *Info: macro .*
