[^:]*: Assembler messages:
[^:]*:3: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:4: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:5: Error: bad type in SIMD instruction -- `vfma.f64 q0,q1,q2'
[^:]*:6: Error: bad type in SIMD instruction -- `vfma.32 q0,q1,q2'
[^:]*:7: Error: bad type in SIMD instruction -- `vfms.f64 q0,q1,q2'
[^:]*:8: Error: bad type in SIMD instruction -- `vfms.32 q0,q1,q2'
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:13: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:27: Error: syntax error -- `vfmaeq.f16 q0,q1,q2'
[^:]*:28: Error: syntax error -- `vfmaeq.f16 q0,q1,q2'
[^:]*:30: Error: syntax error -- `vfmaeq.f16 q0,q1,q2'
[^:]*:31: Error: vector predicated instruction should be in VPT/VPST block -- `vfmat.f16 q0,q1,q2'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vfma.f16 q0,q1,q2'
[^:]*:35: Error: syntax error -- `vfmseq.f16 q0,q1,q2'
[^:]*:36: Error: syntax error -- `vfmseq.f16 q0,q1,q2'
[^:]*:38: Error: syntax error -- `vfmseq.f16 q0,q1,q2'
[^:]*:39: Error: vector predicated instruction should be in VPT/VPST block -- `vfmst.f16 q0,q1,q2'
[^:]*:41: Error: instruction missing MVE vector predication code -- `vfms.f16 q0,q1,q2'
