	vandn.vv v4, v8, v12
	vandn.vv v4, v8, v12, v0.t
	vandn.vx v4, v8, a1
	vandn.vx v4, v8, a1, v0.t
	vbrev.v v4, v8
	vbrev.v v4, v8, v0.t
	vbrev8.v v4, v8
	vbrev8.v v4, v8, v0.t
	vrev8.v v4, v8
	vrev8.v v4, v8, v0.t
	vrev8.v v4, v8
	vrev8.v v4, v8, v0.t
	vclz.v v4, v8
	vclz.v v4, v8, v0.t
	vctz.v v4, v8
	vctz.v v4, v8, v0.t
	vcpop.v v4, v8
	vcpop.v v4, v8, v0.t
	vrol.vv v4, v8, v12
	vrol.vv v4, v8, v12, v0.t
	vrol.vx v4, v8, a1
	vrol.vx v4, v8, a1, v0.t
	vror.vv v4, v8, v12
	vror.vv v4, v8, v12, v0.t
	vror.vx v4, v8, a1
	vror.vx v4, v8, a1, v0.t
	vror.vi v4, v8, 0
	vror.vi v4, v8, 63, v0.t
	vwsll.vv v4, v8, v12
	vwsll.vv v4, v8, v12, v0.t
	vwsll.vx v4, v8, a1
	vwsll.vx v4, v8, a1, v0.t
	vwsll.vi v4, v8, 0
	vwsll.vi v4, v8, 31, v0.t
