#source: ./clrpsw.s
#objdump: -dr

.*:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	7f b9                         	clrpsw	u
   2:	7f b8                         	clrpsw	i
   4:	7f b3                         	clrpsw	o
   6:	7f b2                         	clrpsw	s
   8:	7f b1                         	clrpsw	z
   a:	7f b0                         	clrpsw	c
