	bmopa	0, p0/m, p0/m, z0.s, z0.s
	bmopa	za0.s, 0, p0/m, z0.s, z0.s
	bmopa	za0.s, p0/m, 0, z0.s, z0.s
	bmopa	za0.s, p0/m, p0/m, 0, z0.s
	bmopa	za0.s, p0/m, p0/m, z0.s, 0

	bmopa	za0.b, p0/m, p0/m, z0.b, z0.b
	bmopa	za0.b, p0/m, p0/m, z0.s, z0.s
	bmopa	za0.s, p0/m, p0/m, z0.b, z0.b
	bmopa	za4.s, p0/m, p0/m, z0.s, z0.s
	bmopa	za0.s, p8/m, p0/m, z0.s, z0.s
	bmopa	za4.s, p0/m, p8/m, z0.s, z0.s
