[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzs { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z12\.s,z13\.s ?},{ ?z14\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fcvtzu { ?z16\.s ?- ?z19\.s ?},{ ?z12\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frinta { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintm { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintn { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `frintp { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `scvtf { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z0\.s,z1\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z30\.s,z31\.s ?},{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z0\.s,z1\.s ?},{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z10\.s,z11\.s ?},{ ?z26\.s ?- ?z27\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z0\.s ?- ?z3\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z28\.s ?- ?z31\.s ?},{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z0\.s ?- ?z3\.s ?},{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `ucvtf { ?z24\.s ?- ?z27\.s ?},{ ?z8\.s ?- ?z11\.s ?}'
