[^:]*: Assembler messages:
[^:]*:4: Error: bad type in SIMD instruction -- `vabav.s64 r0,q0,q1'
[^:]*:5: Error: bad type in SIMD instruction -- `vabav.f16 r0,q0,q1'
[^:]*:6: Error: bad type in SIMD instruction -- `vabav.f32 r0,q0,q1'
[^:]*:7: Error: bad type in SIMD instruction -- `vabav.p8 r0,q0,q1'
[^:]*:8: Error: bad type in SIMD instruction -- `vabav.p16 r0,q0,q1'
[^:]*:9: Error: r13 not allowed here -- `vabav.s32 r13,q0,q1'
[^:]*:10: Error: r15 not allowed here -- `vabav.s32 r15,q0,q1'
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Error: syntax error -- `vabaveq.s32 r0,q0,q1'
[^:]*:19: Error: syntax error -- `vabaveq.s32 r0,q0,q1'
[^:]*:21: Error: vector predicated instruction should be in VPT/VPST block -- `vabavt.s32 r0,q0,q1'
[^:]*:22: Error: vector predicated instruction should be in VPT/VPST block -- `vabavt.s32 r0,q0,q1'
