[^:]*: Assembler messages:
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:18: Error: selected FPU does not support instruction -- `vcmp.f32 eq,q0,q1'
[^:]*:19: Error: selected FPU does not support instruction -- `vcmp.f32 eq,q0,r1'
[^:]*:20: Error: bad type in SIMD instruction -- `vcmp.i64 eq,q0,q1'
[^:]*:21: Error: invalid condition -- `vcmp.s32 eq,q0,q1'
[^:]*:22: Error: invalid condition -- `vcmp.s16 cs,q0,q1'
[^:]*:23: Error: invalid condition -- `vcmp.u8 le,q0,q1'
[^:]*:24: Error: condition required -- `vcmp.s16 q0,q1'
[^:]*:25: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:27: Error: syntax error -- `vcmpeq.i32 eq,q0,q1'
[^:]*:28: Error: syntax error -- `vcmpeq.i32 eq,q0,q1'
[^:]*:30: Error: syntax error -- `vcmpeq.i32 eq,q0,q1'
[^:]*:31: Error: vector predicated instruction should be in VPT/VPST block -- `vcmpt.i32 eq,q0,q1'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vcmp.i32 eq,q0,q1'
[^:]*:35: Error: syntax error -- `vcmpeq.i32 eq,q0,r1'
[^:]*:36: Error: syntax error -- `vcmpeq.i32 eq,q0,r1'
[^:]*:38: Error: syntax error -- `vcmpeq.i32 eq,q0,r1'
[^:]*:39: Error: vector predicated instruction should be in VPT/VPST block -- `vcmpt.i32 eq,q0,r1'
[^:]*:41: Error: instruction missing MVE vector predication code -- `vcmp.i32 eq,q0,r1'
