# Illegal operand of atomic memory access instruction.
amcas.b $r1,$r1,$r2
amcas.b $r1,$r2,$r1
amcas.h $r1,$r1,$r2
amcas.h $r1,$r2,$r1
amcas.w $r1,$r1,$r2
amcas.w $r1,$r2,$r1
amcas.d $r1,$r1,$r2
amcas.d $r1,$r2,$r1
amcas_db.b $r1,$r1,$r2
amcas_db.b $r1,$r2,$r1
amcas_db.h $r1,$r1,$r2
amcas_db.h $r1,$r2,$r1
amcas_db.w $r1,$r1,$r2
amcas_db.w $r1,$r2,$r1
amcas_db.d $r1,$r1,$r2
amcas_db.d $r1,$r2,$r1
amswap.b $r1,$r1,$r2
amswap.b $r1,$r2,$r1
amswap.h $r1,$r1,$r2
amswap.h $r1,$r2,$r1
amadd.b $r1,$r1,$r2
amadd.b $r1,$r2,$r1
amadd.h $r1,$r1,$r2
amadd.h $r1,$r2,$r1
amswap_db.b $r1,$r1,$r2
amswap_db.b $r1,$r2,$r1
amswap_db.h $r1,$r1,$r2
amswap_db.h $r1,$r2,$r1
amadd_db.b $r1,$r1,$r2
amadd_db.b $r1,$r2,$r1
amadd_db.h $r1,$r1,$r2
amadd_db.h $r1,$r2,$r1
amswap.w $r1,$r1,$r2
amswap.w $r1,$r2,$r1
amswap.d $r1,$r1,$r2
amswap.d $r1,$r2,$r1
amadd.w $r1,$r1,$r2
amadd.w $r1,$r2,$r1
amadd.d $r1,$r1,$r2
amadd.d $r1,$r2,$r1
amand.w $r1,$r1,$r2
amand.w $r1,$r2,$r1
amand.d $r1,$r1,$r2
amand.d $r1,$r2,$r1
amor.w $r1,$r1,$r2
amor.w $r1,$r2,$r1
amor.d $r1,$r1,$r2
amor.d $r1,$r2,$r1
amxor.w $r1,$r1,$r2
amxor.w $r1,$r2,$r1
amxor.d $r1,$r1,$r2
amxor.d $r1,$r2,$r1
ammax.w $r1,$r1,$r2
ammax.w $r1,$r2,$r1
ammax.d $r1,$r1,$r2
ammax.d $r1,$r2,$r1
ammin.w $r1,$r1,$r2
ammin.w $r1,$r2,$r1
ammin.d $r1,$r1,$r2
ammin.d $r1,$r2,$r1
ammax.wu $r1,$r1,$r2
ammax.wu $r1,$r2,$r1
ammax.du $r1,$r1,$r2
ammax.du $r1,$r2,$r1
ammin.wu $r1,$r1,$r2
ammin.wu $r1,$r2,$r1
ammin.du $r1,$r1,$r2
ammin.du $r1,$r2,$r1
amswap_db.w $r1,$r1,$r2
amswap_db.w $r1,$r2,$r1
amswap_db.d $r1,$r1,$r2
amswap_db.d $r1,$r2,$r1
amadd_db.w $r1,$r1,$r2
amadd_db.w $r1,$r2,$r1
amadd_db.d $r1,$r1,$r2
amadd_db.d $r1,$r2,$r1
amand_db.w $r1,$r1,$r2
amand_db.w $r1,$r2,$r1
amand_db.d $r1,$r1,$r2
amand_db.d $r1,$r2,$r1
amor_db.w $r1,$r1,$r2
amor_db.w $r1,$r2,$r1
amor_db.d $r1,$r1,$r2
amor_db.d $r1,$r2,$r1
amxor_db.w $r1,$r1,$r2
amxor_db.w $r1,$r2,$r1
amxor_db.d $r1,$r1,$r2
amxor_db.d $r1,$r2,$r1
ammax_db.w $r1,$r1,$r2
ammax_db.w $r1,$r2,$r1
ammax_db.d $r1,$r1,$r2
ammax_db.d $r1,$r2,$r1
ammin_db.w $r1,$r1,$r2
ammin_db.w $r1,$r2,$r1
ammin_db.d $r1,$r1,$r2
ammin_db.d $r1,$r2,$r1
ammax_db.wu $r1,$r1,$r2
ammax_db.wu $r1,$r2,$r1
ammax_db.du $r1,$r1,$r2
ammax_db.du $r1,$r2,$r1
ammin_db.wu $r1,$r1,$r2
ammin_db.wu $r1,$r2,$r1
ammin_db.du $r1,$r1,$r2
ammin_db.du $r1,$r2,$r1

# Illegal operand of bstr(ins|pick).[wd]
bstrins.w $r1,$r2,0,8
bstrins.d $r1,$r2,0,8
bstrpick.w $r1,$r2,0,8
bstrpick.d $r1,$r2,0,8

# Illegal operand of csrxchg/gcsrxchg
csrxchg $r0,$r0,1
csrxchg $r0,$r1,1
gcsrxchg $r0,$r0,1
gcsrxchg $r0,$r1,1
