
	.section	.none,"dr3"
	.section	.zero,"dr3"
	.ascii	""
	.section	.one,"dr3"
	.ascii	"1"
	.section	.two,"dr3"
	.ascii	"12"
	.section	.three,"dr3"
	.ascii	"123"
	.section	.four,"dr3"
	.ascii	"1234"
	.section	.five,"dr3"
	.ascii	"12345"
	.section	.six,"dr3"
	.ascii	"123456"
	.section	.seven,"dr3"
	.ascii	"1234567"
	.section	.eight,"dr3"
	.ascii	"12345678"
	.section	.nine,"dr3"
	.ascii	"123456789"
	.section	.ten,"dr3"
	.ascii	"1234567890"
	.end
