.*: Assembler messages:
.*:4: Error: .*
.*:5: Error: .*
.*:6: Error: .*
.*:8: Error: .*
.*:9: Error: .*
.*:10: Error: .*
.*:11: Error: .*
.*:12: Error: .*
.*:15: Error:.* ambiguous .* `vcvtpd2dq'
.*:16: Error:.* ambiguous .* `vcvtpd2ps'
.*:17: Error:.* ambiguous .* `vcvttpd2dq'
GAS LISTING .*
#pass
