vfmadd.s	$vr0, $vr1, $vr2, $vr3
vfmsub.s	$vr0, $vr1, $vr2, $vr3
vfnmadd.s	$vr0, $vr1, $vr2, $vr3
vfnmsub.s	$vr0, $vr1, $vr2, $vr3
xvfmadd.s	$xr0, $xr1, $xr2, $xr3
xvfmsub.s	$xr0, $xr1, $xr2, $xr3
xvfnmadd.s	$xr0, $xr1, $xr2, $xr3
xvfnmsub.s	$xr0, $xr1, $xr2, $xr3
vfcmp.caf.s	$vr0, $vr1, $vr2
vfcmp.saf.s	$vr0, $vr1, $vr2
vfcmp.clt.s	$vr0, $vr1, $vr2
vfcmp.slt.s	$vr0, $vr1, $vr2
vfcmp.ceq.s	$vr0, $vr1, $vr2
vfcmp.seq.s	$vr0, $vr1, $vr2
vfcmp.cle.s	$vr0, $vr1, $vr2
vfcmp.sle.s	$vr0, $vr1, $vr2
vfcmp.cun.s	$vr0, $vr1, $vr2
vfcmp.sun.s	$vr0, $vr1, $vr2
vfcmp.cult.s	$vr0, $vr1, $vr2
vfcmp.sult.s	$vr0, $vr1, $vr2
vfcmp.cueq.s	$vr0, $vr1, $vr2
vfcmp.sueq.s	$vr0, $vr1, $vr2
vfcmp.cule.s	$vr0, $vr1, $vr2
vfcmp.sule.s	$vr0, $vr1, $vr2
vfcmp.cne.s	$vr0, $vr1, $vr2
vfcmp.sne.s	$vr0, $vr1, $vr2
vfcmp.cor.s	$vr0, $vr1, $vr2
vfcmp.sor.s	$vr0, $vr1, $vr2
vfcmp.cune.s	$vr0, $vr1, $vr2
vfcmp.sune.s	$vr0, $vr1, $vr2
xvfcmp.caf.s	$xr0, $xr1, $xr2
xvfcmp.saf.s	$xr0, $xr1, $xr2
xvfcmp.clt.s	$xr0, $xr1, $xr2
xvfcmp.slt.s	$xr0, $xr1, $xr2
xvfcmp.ceq.s	$xr0, $xr1, $xr2
xvfcmp.seq.s	$xr0, $xr1, $xr2
xvfcmp.cle.s	$xr0, $xr1, $xr2
xvfcmp.sle.s	$xr0, $xr1, $xr2
xvfcmp.cun.s	$xr0, $xr1, $xr2
xvfcmp.sun.s	$xr0, $xr1, $xr2
xvfcmp.cult.s	$xr0, $xr1, $xr2
xvfcmp.sult.s	$xr0, $xr1, $xr2
xvfcmp.cueq.s	$xr0, $xr1, $xr2
xvfcmp.sueq.s	$xr0, $xr1, $xr2
xvfcmp.cule.s	$xr0, $xr1, $xr2
xvfcmp.sule.s	$xr0, $xr1, $xr2
xvfcmp.cne.s	$xr0, $xr1, $xr2
xvfcmp.sne.s	$xr0, $xr1, $xr2
xvfcmp.cor.s	$xr0, $xr1, $xr2
xvfcmp.sor.s	$xr0, $xr1, $xr2
xvfcmp.cune.s	$xr0, $xr1, $xr2
xvfcmp.sune.s	$xr0, $xr1, $xr2
vbitsel.v	$vr0, $vr1, $vr2, $vr3
xvbitsel.v	$xr0, $xr1, $xr2, $xr3
vshuf.b	$vr0, $vr1, $vr2, $vr3
xvshuf.b	$xr0, $xr1, $xr2, $xr3
vfmadd.d	$vr0, $vr1, $vr2, $vr3
vfmsub.d	$vr0, $vr1, $vr2, $vr3
vfnmadd.d	$vr0, $vr1, $vr2, $vr3
vfnmsub.d	$vr0, $vr1, $vr2, $vr3
xvfmadd.d	$xr0, $xr1, $xr2, $xr3
xvfmsub.d	$xr0, $xr1, $xr2, $xr3
xvfnmadd.d	$xr0, $xr1, $xr2, $xr3
xvfnmsub.d	$xr0, $xr1, $xr2, $xr3
vfcmp.caf.d	$vr0, $vr1, $vr2
vfcmp.saf.d	$vr0, $vr1, $vr2
vfcmp.clt.d	$vr0, $vr1, $vr2
vfcmp.slt.d	$vr0, $vr1, $vr2
vfcmp.ceq.d	$vr0, $vr1, $vr2
vfcmp.seq.d	$vr0, $vr1, $vr2
vfcmp.cle.d	$vr0, $vr1, $vr2
vfcmp.sle.d	$vr0, $vr1, $vr2
vfcmp.cun.d	$vr0, $vr1, $vr2
vfcmp.sun.d	$vr0, $vr1, $vr2
vfcmp.cult.d	$vr0, $vr1, $vr2
vfcmp.sult.d	$vr0, $vr1, $vr2
vfcmp.cueq.d	$vr0, $vr1, $vr2
vfcmp.sueq.d	$vr0, $vr1, $vr2
vfcmp.cule.d	$vr0, $vr1, $vr2
vfcmp.sule.d	$vr0, $vr1, $vr2
vfcmp.cne.d	$vr0, $vr1, $vr2
vfcmp.sne.d	$vr0, $vr1, $vr2
vfcmp.cor.d	$vr0, $vr1, $vr2
vfcmp.sor.d	$vr0, $vr1, $vr2
vfcmp.cune.d	$vr0, $vr1, $vr2
vfcmp.sune.d	$vr0, $vr1, $vr2
xvfcmp.caf.d	$xr0, $xr1, $xr2
xvfcmp.saf.d	$xr0, $xr1, $xr2
xvfcmp.clt.d	$xr0, $xr1, $xr2
xvfcmp.slt.d	$xr0, $xr1, $xr2
xvfcmp.ceq.d	$xr0, $xr1, $xr2
xvfcmp.seq.d	$xr0, $xr1, $xr2
xvfcmp.cle.d	$xr0, $xr1, $xr2
xvfcmp.sle.d	$xr0, $xr1, $xr2
xvfcmp.cun.d	$xr0, $xr1, $xr2
xvfcmp.sun.d	$xr0, $xr1, $xr2
xvfcmp.cult.d	$xr0, $xr1, $xr2
xvfcmp.sult.d	$xr0, $xr1, $xr2
xvfcmp.cueq.d	$xr0, $xr1, $xr2
xvfcmp.sueq.d	$xr0, $xr1, $xr2
xvfcmp.cule.d	$xr0, $xr1, $xr2
xvfcmp.sule.d	$xr0, $xr1, $xr2
xvfcmp.cne.d	$xr0, $xr1, $xr2
xvfcmp.sne.d	$xr0, $xr1, $xr2
xvfcmp.cor.d	$xr0, $xr1, $xr2
xvfcmp.sor.d	$xr0, $xr1, $xr2
xvfcmp.cune.d	$xr0, $xr1, $xr2
xvfcmp.sune.d	$xr0, $xr1, $xr2
vld	$vr0, $r1, 1
vst	$vr0, $r1, 1
xvld	$xr0, $r1, 1
xvst	$xr0, $r1, 1
vldx	$vr0, $r1, $r2
vstx	$vr0, $r1, $r2
xvldx	$xr0, $r1, $r2
xvstx	$xr0, $r1, $r2
vldrepl.d	$vr0, $r1, 1000
vldrepl.w	$vr0, $r1, 100
vldrepl.h	$vr0, $r1, 10
vldrepl.b	$vr0, $r1, 1
vstelm.d	$vr0, $r1, 1000, 1
vstelm.w	$vr0, $r1, 100, 1
vstelm.h	$vr0, $r1, 10, 1
vstelm.b	$vr0, $r1, 1, 1
xvldrepl.d	$xr0, $r1, 1000
xvldrepl.w	$xr0, $r1, 100
xvldrepl.h	$xr0, $r1, 10
xvldrepl.b	$xr0, $r1, 1
xvstelm.d	$xr0, $r1, 1000, 1
xvstelm.w	$xr0, $r1, 100, 1
xvstelm.h	$xr0, $r1, 10, 1
xvstelm.b	$xr0, $r1, 1, 1
vseq.b	$vr0, $vr1, $vr2
vseq.h	$vr0, $vr1, $vr2
vseq.w	$vr0, $vr1, $vr2
vseq.d	$vr0, $vr1, $vr2
vsle.b	$vr0, $vr1, $vr2
vsle.h	$vr0, $vr1, $vr2
vsle.w	$vr0, $vr1, $vr2
vsle.d	$vr0, $vr1, $vr2
vsle.bu	$vr0, $vr1, $vr2
vsle.hu	$vr0, $vr1, $vr2
vsle.wu	$vr0, $vr1, $vr2
vsle.du	$vr0, $vr1, $vr2
vslt.b	$vr0, $vr1, $vr2
vslt.h	$vr0, $vr1, $vr2
vslt.w	$vr0, $vr1, $vr2
vslt.d	$vr0, $vr1, $vr2
vslt.bu	$vr0, $vr1, $vr2
vslt.hu	$vr0, $vr1, $vr2
vslt.wu	$vr0, $vr1, $vr2
vslt.du	$vr0, $vr1, $vr2
vadd.b	$vr0, $vr1, $vr2
vadd.h	$vr0, $vr1, $vr2
vadd.w	$vr0, $vr1, $vr2
vadd.d	$vr0, $vr1, $vr2
vsub.b	$vr0, $vr1, $vr2
vsub.h	$vr0, $vr1, $vr2
vsub.w	$vr0, $vr1, $vr2
vsub.d	$vr0, $vr1, $vr2
vsadd.b	$vr0, $vr1, $vr2
vsadd.h	$vr0, $vr1, $vr2
vsadd.w	$vr0, $vr1, $vr2
vsadd.d	$vr0, $vr1, $vr2
vssub.b	$vr0, $vr1, $vr2
vssub.h	$vr0, $vr1, $vr2
vssub.w	$vr0, $vr1, $vr2
vssub.d	$vr0, $vr1, $vr2
vsadd.bu	$vr0, $vr1, $vr2
vsadd.hu	$vr0, $vr1, $vr2
vsadd.wu	$vr0, $vr1, $vr2
vsadd.du	$vr0, $vr1, $vr2
vssub.bu	$vr0, $vr1, $vr2
vssub.hu	$vr0, $vr1, $vr2
vssub.wu	$vr0, $vr1, $vr2
vssub.du	$vr0, $vr1, $vr2
vhaddw.h.b	$vr0, $vr1, $vr2
vhaddw.w.h	$vr0, $vr1, $vr2
vhaddw.d.w	$vr0, $vr1, $vr2
vhaddw.q.d	$vr0, $vr1, $vr2
vhsubw.h.b	$vr0, $vr1, $vr2
vhsubw.w.h	$vr0, $vr1, $vr2
vhsubw.d.w	$vr0, $vr1, $vr2
vhsubw.q.d	$vr0, $vr1, $vr2
vhaddw.hu.bu	$vr0, $vr1, $vr2
vhaddw.wu.hu	$vr0, $vr1, $vr2
vhaddw.du.wu	$vr0, $vr1, $vr2
vhaddw.qu.du	$vr0, $vr1, $vr2
vhsubw.hu.bu	$vr0, $vr1, $vr2
vhsubw.wu.hu	$vr0, $vr1, $vr2
vhsubw.du.wu	$vr0, $vr1, $vr2
vhsubw.qu.du	$vr0, $vr1, $vr2
vadda.b	$vr0, $vr1, $vr2
vadda.h	$vr0, $vr1, $vr2
vadda.w	$vr0, $vr1, $vr2
vadda.d	$vr0, $vr1, $vr2
vabsd.b	$vr0, $vr1, $vr2
vabsd.h	$vr0, $vr1, $vr2
vabsd.w	$vr0, $vr1, $vr2
vabsd.d	$vr0, $vr1, $vr2
vabsd.bu	$vr0, $vr1, $vr2
vabsd.hu	$vr0, $vr1, $vr2
vabsd.wu	$vr0, $vr1, $vr2
vabsd.du	$vr0, $vr1, $vr2
vavg.b	$vr0, $vr1, $vr2
vavg.h	$vr0, $vr1, $vr2
vavg.w	$vr0, $vr1, $vr2
vavg.d	$vr0, $vr1, $vr2
vavg.bu	$vr0, $vr1, $vr2
vavg.hu	$vr0, $vr1, $vr2
vavg.wu	$vr0, $vr1, $vr2
vavg.du	$vr0, $vr1, $vr2
vavgr.b	$vr0, $vr1, $vr2
vavgr.h	$vr0, $vr1, $vr2
vavgr.w	$vr0, $vr1, $vr2
vavgr.d	$vr0, $vr1, $vr2
vavgr.bu	$vr0, $vr1, $vr2
vavgr.hu	$vr0, $vr1, $vr2
vavgr.wu	$vr0, $vr1, $vr2
vavgr.du	$vr0, $vr1, $vr2
vmax.b	$vr0, $vr1, $vr2
vmax.h	$vr0, $vr1, $vr2
vmax.w	$vr0, $vr1, $vr2
vmax.d	$vr0, $vr1, $vr2
vmin.b	$vr0, $vr1, $vr2
vmin.h	$vr0, $vr1, $vr2
vmin.w	$vr0, $vr1, $vr2
vmin.d	$vr0, $vr1, $vr2
vmax.bu	$vr0, $vr1, $vr2
vmax.hu	$vr0, $vr1, $vr2
vmax.wu	$vr0, $vr1, $vr2
vmax.du	$vr0, $vr1, $vr2
vmin.bu	$vr0, $vr1, $vr2
vmin.hu	$vr0, $vr1, $vr2
vmin.wu	$vr0, $vr1, $vr2
vmin.du	$vr0, $vr1, $vr2
vmul.b	$vr0, $vr1, $vr2
vmul.h	$vr0, $vr1, $vr2
vmul.w	$vr0, $vr1, $vr2
vmul.d	$vr0, $vr1, $vr2
vmuh.b	$vr0, $vr1, $vr2
vmuh.h	$vr0, $vr1, $vr2
vmuh.w	$vr0, $vr1, $vr2
vmuh.d	$vr0, $vr1, $vr2
vmuh.bu	$vr0, $vr1, $vr2
vmuh.hu	$vr0, $vr1, $vr2
vmuh.wu	$vr0, $vr1, $vr2
vmuh.du	$vr0, $vr1, $vr2
vmadd.b	$vr0, $vr1, $vr2
vmadd.h	$vr0, $vr1, $vr2
vmadd.w	$vr0, $vr1, $vr2
vmadd.d	$vr0, $vr1, $vr2
vmsub.b	$vr0, $vr1, $vr2
vmsub.h	$vr0, $vr1, $vr2
vmsub.w	$vr0, $vr1, $vr2
vmsub.d	$vr0, $vr1, $vr2
vdiv.b	$vr0, $vr1, $vr2
vdiv.h	$vr0, $vr1, $vr2
vdiv.w	$vr0, $vr1, $vr2
vdiv.d	$vr0, $vr1, $vr2
vmod.b	$vr0, $vr1, $vr2
vmod.h	$vr0, $vr1, $vr2
vmod.w	$vr0, $vr1, $vr2
vmod.d	$vr0, $vr1, $vr2
vdiv.bu	$vr0, $vr1, $vr2
vdiv.hu	$vr0, $vr1, $vr2
vdiv.wu	$vr0, $vr1, $vr2
vdiv.du	$vr0, $vr1, $vr2
vmod.bu	$vr0, $vr1, $vr2
vmod.hu	$vr0, $vr1, $vr2
vmod.wu	$vr0, $vr1, $vr2
vmod.du	$vr0, $vr1, $vr2
vsll.b	$vr0, $vr1, $vr2
vsll.h	$vr0, $vr1, $vr2
vsll.w	$vr0, $vr1, $vr2
vsll.d	$vr0, $vr1, $vr2
vsrl.b	$vr0, $vr1, $vr2
vsrl.h	$vr0, $vr1, $vr2
vsrl.w	$vr0, $vr1, $vr2
vsrl.d	$vr0, $vr1, $vr2
vsra.b	$vr0, $vr1, $vr2
vsra.h	$vr0, $vr1, $vr2
vsra.w	$vr0, $vr1, $vr2
vsra.d	$vr0, $vr1, $vr2
vrotr.b	$vr0, $vr1, $vr2
vrotr.h	$vr0, $vr1, $vr2
vrotr.w	$vr0, $vr1, $vr2
vrotr.d	$vr0, $vr1, $vr2
vsrlr.b	$vr0, $vr1, $vr2
vsrlr.h	$vr0, $vr1, $vr2
vsrlr.w	$vr0, $vr1, $vr2
vsrlr.d	$vr0, $vr1, $vr2
vsrar.b	$vr0, $vr1, $vr2
vsrar.h	$vr0, $vr1, $vr2
vsrar.w	$vr0, $vr1, $vr2
vsrar.d	$vr0, $vr1, $vr2
vsrln.b.h	$vr0, $vr1, $vr2
vsrln.h.w	$vr0, $vr1, $vr2
vsrln.w.d	$vr0, $vr1, $vr2
vsran.b.h	$vr0, $vr1, $vr2
vsran.h.w	$vr0, $vr1, $vr2
vsran.w.d	$vr0, $vr1, $vr2
vsrlrn.b.h	$vr0, $vr1, $vr2
vsrlrn.h.w	$vr0, $vr1, $vr2
vsrlrn.w.d	$vr0, $vr1, $vr2
vsrarn.b.h	$vr0, $vr1, $vr2
vsrarn.h.w	$vr0, $vr1, $vr2
vsrarn.w.d	$vr0, $vr1, $vr2
vssrln.b.h	$vr0, $vr1, $vr2
vssrln.h.w	$vr0, $vr1, $vr2
vssrln.w.d	$vr0, $vr1, $vr2
vssran.b.h	$vr0, $vr1, $vr2
vssran.h.w	$vr0, $vr1, $vr2
vssran.w.d	$vr0, $vr1, $vr2
vssrlrn.b.h	$vr0, $vr1, $vr2
vssrlrn.h.w	$vr0, $vr1, $vr2
vssrlrn.w.d	$vr0, $vr1, $vr2
vssrarn.b.h	$vr0, $vr1, $vr2
vssrarn.h.w	$vr0, $vr1, $vr2
vssrarn.w.d	$vr0, $vr1, $vr2
vssrln.bu.h	$vr0, $vr1, $vr2
vssrln.hu.w	$vr0, $vr1, $vr2
vssrln.wu.d	$vr0, $vr1, $vr2
vssran.bu.h	$vr0, $vr1, $vr2
vssran.hu.w	$vr0, $vr1, $vr2
vssran.wu.d	$vr0, $vr1, $vr2
vssrlrn.bu.h	$vr0, $vr1, $vr2
vssrlrn.hu.w	$vr0, $vr1, $vr2
vssrlrn.wu.d	$vr0, $vr1, $vr2
vssrarn.bu.h	$vr0, $vr1, $vr2
vssrarn.hu.w	$vr0, $vr1, $vr2
vssrarn.wu.d	$vr0, $vr1, $vr2
vbitclr.b	$vr0, $vr1, $vr2
vbitclr.h	$vr0, $vr1, $vr2
vbitclr.w	$vr0, $vr1, $vr2
vbitclr.d	$vr0, $vr1, $vr2
vbitset.b	$vr0, $vr1, $vr2
vbitset.h	$vr0, $vr1, $vr2
vbitset.w	$vr0, $vr1, $vr2
vbitset.d	$vr0, $vr1, $vr2
vbitrev.b	$vr0, $vr1, $vr2
vbitrev.h	$vr0, $vr1, $vr2
vbitrev.w	$vr0, $vr1, $vr2
vbitrev.d	$vr0, $vr1, $vr2
vpackev.b	$vr0, $vr1, $vr2
vpackev.h	$vr0, $vr1, $vr2
vpackev.w	$vr0, $vr1, $vr2
vpackev.d	$vr0, $vr1, $vr2
vpackod.b	$vr0, $vr1, $vr2
vpackod.h	$vr0, $vr1, $vr2
vpackod.w	$vr0, $vr1, $vr2
vpackod.d	$vr0, $vr1, $vr2
vilvl.b	$vr0, $vr1, $vr2
vilvl.h	$vr0, $vr1, $vr2
vilvl.w	$vr0, $vr1, $vr2
vilvl.d	$vr0, $vr1, $vr2
vilvh.b	$vr0, $vr1, $vr2
vilvh.h	$vr0, $vr1, $vr2
vilvh.w	$vr0, $vr1, $vr2
vilvh.d	$vr0, $vr1, $vr2
vpickev.b	$vr0, $vr1, $vr2
vpickev.h	$vr0, $vr1, $vr2
vpickev.w	$vr0, $vr1, $vr2
vpickev.d	$vr0, $vr1, $vr2
vpickod.b	$vr0, $vr1, $vr2
vpickod.h	$vr0, $vr1, $vr2
vpickod.w	$vr0, $vr1, $vr2
vpickod.d	$vr0, $vr1, $vr2
vreplve.b	$vr0, $vr1, $r2
vreplve.h	$vr0, $vr1, $r2
vreplve.w	$vr0, $vr1, $r2
vreplve.d	$vr0, $vr1, $r2
vand.v	$vr0, $vr1, $vr2
vor.v	$vr0, $vr1, $vr2
vxor.v	$vr0, $vr1, $vr2
vnor.v	$vr0, $vr1, $vr2
vandn.v	$vr0, $vr1, $vr2
vorn.v	$vr0, $vr1, $vr2
vfrstp.b	$vr0, $vr1, $vr2
vfrstp.h	$vr0, $vr1, $vr2
vadd.q	$vr0, $vr1, $vr2
vsub.q	$vr0, $vr1, $vr2
vsigncov.b	$vr0, $vr1, $vr2
vsigncov.h	$vr0, $vr1, $vr2
vsigncov.w	$vr0, $vr1, $vr2
vsigncov.d	$vr0, $vr1, $vr2
vfadd.s	$vr0, $vr1, $vr2
vfadd.d	$vr0, $vr1, $vr2
vfsub.s	$vr0, $vr1, $vr2
vfsub.d	$vr0, $vr1, $vr2
vfmul.s	$vr0, $vr1, $vr2
vfmul.d	$vr0, $vr1, $vr2
vfdiv.s	$vr0, $vr1, $vr2
vfdiv.d	$vr0, $vr1, $vr2
vfmax.s	$vr0, $vr1, $vr2
vfmax.d	$vr0, $vr1, $vr2
vfmin.s	$vr0, $vr1, $vr2
vfmin.d	$vr0, $vr1, $vr2
vfmaxa.s	$vr0, $vr1, $vr2
vfmaxa.d	$vr0, $vr1, $vr2
vfmina.s	$vr0, $vr1, $vr2
vfmina.d	$vr0, $vr1, $vr2
vfcvt.h.s	$vr0, $vr1, $vr2
vfcvt.s.d	$vr0, $vr1, $vr2
vffint.s.l	$vr0, $vr1, $vr2
vftint.w.d	$vr0, $vr1, $vr2
vftintrm.w.d	$vr0, $vr1, $vr2
vftintrp.w.d	$vr0, $vr1, $vr2
vftintrz.w.d	$vr0, $vr1, $vr2
vftintrne.w.d	$vr0, $vr1, $vr2
vshuf.h	$vr0, $vr1, $vr2
vshuf.w	$vr0, $vr1, $vr2
vshuf.d	$vr0, $vr1, $vr2
vseqi.b	$vr0, $vr1, 1
vseqi.h	$vr0, $vr1, 1
vseqi.w	$vr0, $vr1, 1
vseqi.d	$vr0, $vr1, 1
vslei.b	$vr0, $vr1, 1
vslei.h	$vr0, $vr1, 1
vslei.w	$vr0, $vr1, 1
vslei.d	$vr0, $vr1, 1
vslei.bu	$vr0, $vr1, 1
vslei.hu	$vr0, $vr1, 1
vslei.wu	$vr0, $vr1, 1
vslei.du	$vr0, $vr1, 1
vslti.b	$vr0, $vr1, 1
vslti.h	$vr0, $vr1, 1
vslti.w	$vr0, $vr1, 1
vslti.d	$vr0, $vr1, 1
vslti.bu	$vr0, $vr1, 1
vslti.hu	$vr0, $vr1, 1
vslti.wu	$vr0, $vr1, 1
vslti.du	$vr0, $vr1, 1
vaddi.bu	$vr0, $vr1, 1
vaddi.hu	$vr0, $vr1, 1
vaddi.wu	$vr0, $vr1, 1
vaddi.du	$vr0, $vr1, 1
vsubi.bu	$vr0, $vr1, 1
vsubi.hu	$vr0, $vr1, 1
vsubi.wu	$vr0, $vr1, 1
vsubi.du	$vr0, $vr1, 1
vbsll.v	$vr0, $vr1, 1
vbsrl.v	$vr0, $vr1, 1
vmaxi.b	$vr0, $vr1, 1
vmaxi.h	$vr0, $vr1, 1
vmaxi.w	$vr0, $vr1, 1
vmaxi.d	$vr0, $vr1, 1
vmini.b	$vr0, $vr1, 1
vmini.h	$vr0, $vr1, 1
vmini.w	$vr0, $vr1, 1
vmini.d	$vr0, $vr1, 1
vmaxi.bu	$vr0, $vr1, 1
vmaxi.hu	$vr0, $vr1, 1
vmaxi.wu	$vr0, $vr1, 1
vmaxi.du	$vr0, $vr1, 1
vmini.bu	$vr0, $vr1, 1
vmini.hu	$vr0, $vr1, 1
vmini.wu	$vr0, $vr1, 1
vmini.du	$vr0, $vr1, 1
vfrstpi.b	$vr0, $vr1, 1
vfrstpi.h	$vr0, $vr1, 1
vclo.b	$vr0, $vr1
vclo.h	$vr0, $vr1
vclo.w	$vr0, $vr1
vclo.d	$vr0, $vr1
vclz.b	$vr0, $vr1
vclz.h	$vr0, $vr1
vclz.w	$vr0, $vr1
vclz.d	$vr0, $vr1
vpcnt.b	$vr0, $vr1
vpcnt.h	$vr0, $vr1
vpcnt.w	$vr0, $vr1
vpcnt.d	$vr0, $vr1
vneg.b	$vr0, $vr1
vneg.h	$vr0, $vr1
vneg.w	$vr0, $vr1
vneg.d	$vr0, $vr1
vmskltz.b	$vr0, $vr1
vmskltz.h	$vr0, $vr1
vmskltz.w	$vr0, $vr1
vmskltz.d	$vr0, $vr1
vmskgez.b	$vr0, $vr1
vmsknz.b	$vr0, $vr1
vseteqz.v	$fcc0, $vr1
vsetnez.v	$fcc0, $vr1
vsetanyeqz.b	$fcc0, $vr1
vsetanyeqz.h	$fcc0, $vr1
vsetanyeqz.w	$fcc0, $vr1
vsetanyeqz.d	$fcc0, $vr1
vsetallnez.b	$fcc0, $vr1
vsetallnez.h	$fcc0, $vr1
vsetallnez.w	$fcc0, $vr1
vsetallnez.d	$fcc0, $vr1
vflogb.s	$vr0, $vr1
vflogb.d	$vr0, $vr1
vfclass.s	$vr0, $vr1
vfclass.d	$vr0, $vr1
vfsqrt.s	$vr0, $vr1
vfsqrt.d	$vr0, $vr1
vfrecip.s	$vr0, $vr1
vfrecip.d	$vr0, $vr1
vfrsqrt.s	$vr0, $vr1
vfrsqrt.d	$vr0, $vr1
vfrint.s	$vr0, $vr1
vfrint.d	$vr0, $vr1
vfrintrm.s	$vr0, $vr1
vfrintrm.d	$vr0, $vr1
vfrintrp.s	$vr0, $vr1
vfrintrp.d	$vr0, $vr1
vfrintrz.s	$vr0, $vr1
vfrintrz.d	$vr0, $vr1
vfrintrne.s	$vr0, $vr1
vfrintrne.d	$vr0, $vr1
vfcvtl.s.h	$vr0, $vr1
vfcvth.s.h	$vr0, $vr1
vfcvtl.d.s	$vr0, $vr1
vfcvth.d.s	$vr0, $vr1
vffint.s.w	$vr0, $vr1
vffint.s.wu	$vr0, $vr1
vffint.d.l	$vr0, $vr1
vffint.d.lu	$vr0, $vr1
vffintl.d.w	$vr0, $vr1
vffinth.d.w	$vr0, $vr1
vftint.w.s	$vr0, $vr1
vftint.l.d	$vr0, $vr1
vftintrm.w.s	$vr0, $vr1
vftintrm.l.d	$vr0, $vr1
vftintrp.w.s	$vr0, $vr1
vftintrp.l.d	$vr0, $vr1
vftintrz.w.s	$vr0, $vr1
vftintrz.l.d	$vr0, $vr1
vftintrne.w.s	$vr0, $vr1
vftintrne.l.d	$vr0, $vr1
vftint.wu.s	$vr0, $vr1
vftint.lu.d	$vr0, $vr1
vftintrz.wu.s	$vr0, $vr1
vftintrz.lu.d	$vr0, $vr1
vftintl.l.s	$vr0, $vr1
vftinth.l.s	$vr0, $vr1
vftintrml.l.s	$vr0, $vr1
vftintrmh.l.s	$vr0, $vr1
vftintrpl.l.s	$vr0, $vr1
vftintrph.l.s	$vr0, $vr1
vftintrzl.l.s	$vr0, $vr1
vftintrzh.l.s	$vr0, $vr1
vftintrnel.l.s	$vr0, $vr1
vftintrneh.l.s	$vr0, $vr1
vexth.h.b	$vr0, $vr1
vexth.w.h	$vr0, $vr1
vexth.d.w	$vr0, $vr1
vexth.q.d	$vr0, $vr1
vexth.hu.bu	$vr0, $vr1
vexth.wu.hu	$vr0, $vr1
vexth.du.wu	$vr0, $vr1
vexth.qu.du	$vr0, $vr1
vreplgr2vr.b	$vr0, $r1
vreplgr2vr.h	$vr0, $r1
vreplgr2vr.w	$vr0, $r1
vreplgr2vr.d	$vr0, $r1
vrotri.b	$vr0, $vr1, 1
vrotri.h	$vr0, $vr1, 1
vrotri.w	$vr0, $vr1, 1
vrotri.d	$vr0, $vr1, 1
vsrlri.b	$vr0, $vr1, 1
vsrlri.h	$vr0, $vr1, 1
vsrlri.w	$vr0, $vr1, 1
vsrlri.d	$vr0, $vr1, 1
vsrari.b	$vr0, $vr1, 1
vsrari.h	$vr0, $vr1, 1
vsrari.w	$vr0, $vr1, 1
vsrari.d	$vr0, $vr1, 1
vinsgr2vr.b	$vr0, $r1, 1
vinsgr2vr.h	$vr0, $r1, 1
vinsgr2vr.w	$vr0, $r1, 1
vinsgr2vr.d	$vr0, $r1, 1
vpickve2gr.b	$r0, $vr1, 1
vpickve2gr.h	$r0, $vr1, 1
vpickve2gr.w	$r0, $vr1, 1
vpickve2gr.d	$r0, $vr1, 1
vpickve2gr.bu	$r0, $vr1, 1
vpickve2gr.hu	$r0, $vr1, 1
vpickve2gr.wu	$r0, $vr1, 1
vpickve2gr.du	$r0, $vr1, 1
vreplvei.b	$vr0, $vr1, 1
vreplvei.h	$vr0, $vr1, 1
vreplvei.w	$vr0, $vr1, 1
vreplvei.d	$vr0, $vr1, 1
vsllwil.h.b	$vr0, $vr1, 1
vsllwil.w.h	$vr0, $vr1, 1
vsllwil.d.w	$vr0, $vr1, 1
vextl.q.d	$vr0, $vr1
vsllwil.hu.bu	$vr0, $vr1, 1
vsllwil.wu.hu	$vr0, $vr1, 1
vsllwil.du.wu	$vr0, $vr1, 1
vextl.qu.du	$vr0, $vr1
vbitclri.b	$vr0, $vr1, 1
vbitclri.h	$vr0, $vr1, 1
vbitclri.w	$vr0, $vr1, 1
vbitclri.d	$vr0, $vr1, 1
vbitseti.b	$vr0, $vr1, 1
vbitseti.h	$vr0, $vr1, 1
vbitseti.w	$vr0, $vr1, 1
vbitseti.d	$vr0, $vr1, 1
vbitrevi.b	$vr0, $vr1, 1
vbitrevi.h	$vr0, $vr1, 1
vbitrevi.w	$vr0, $vr1, 1
vbitrevi.d	$vr0, $vr1, 1
vsat.b	$vr0, $vr1, 1
vsat.h	$vr0, $vr1, 1
vsat.w	$vr0, $vr1, 1
vsat.d	$vr0, $vr1, 1
vsat.bu	$vr0, $vr1, 1
vsat.hu	$vr0, $vr1, 1
vsat.wu	$vr0, $vr1, 1
vsat.du	$vr0, $vr1, 1
vslli.b	$vr0, $vr1, 1
vslli.h	$vr0, $vr1, 1
vslli.w	$vr0, $vr1, 1
vslli.d	$vr0, $vr1, 1
vsrli.b	$vr0, $vr1, 1
vsrli.h	$vr0, $vr1, 1
vsrli.w	$vr0, $vr1, 1
vsrli.d	$vr0, $vr1, 1
vsrai.b	$vr0, $vr1, 1
vsrai.h	$vr0, $vr1, 1
vsrai.w	$vr0, $vr1, 1
vsrai.d	$vr0, $vr1, 1
vsrlni.b.h	$vr0, $vr1, 1
vsrlni.h.w	$vr0, $vr1, 1
vsrlni.w.d	$vr0, $vr1, 1
vsrlni.d.q	$vr0, $vr1, 1
vssrlni.b.h	$vr0, $vr1, 1
vssrlni.h.w	$vr0, $vr1, 1
vssrlni.w.d	$vr0, $vr1, 1
vssrlni.d.q	$vr0, $vr1, 1
vsrlrni.b.h	$vr0, $vr1, 1
vsrlrni.h.w	$vr0, $vr1, 1
vsrlrni.w.d	$vr0, $vr1, 1
vsrlrni.d.q	$vr0, $vr1, 1
vssrlni.bu.h	$vr0, $vr1, 1
vssrlni.hu.w	$vr0, $vr1, 1
vssrlni.wu.d	$vr0, $vr1, 1
vssrlni.du.q	$vr0, $vr1, 1
vssrlrni.b.h	$vr0, $vr1, 1
vssrlrni.h.w	$vr0, $vr1, 1
vssrlrni.w.d	$vr0, $vr1, 1
vssrlrni.d.q	$vr0, $vr1, 1
vssrlrni.bu.h	$vr0, $vr1, 1
vssrlrni.hu.w	$vr0, $vr1, 1
vssrlrni.wu.d	$vr0, $vr1, 1
vssrlrni.du.q	$vr0, $vr1, 1
vsrani.b.h	$vr0, $vr1, 1
vsrani.h.w	$vr0, $vr1, 1
vsrani.w.d	$vr0, $vr1, 1
vsrani.d.q	$vr0, $vr1, 1
vsrarni.b.h	$vr0, $vr1, 1
vsrarni.h.w	$vr0, $vr1, 1
vsrarni.w.d	$vr0, $vr1, 1
vsrarni.d.q	$vr0, $vr1, 1
vssrani.b.h	$vr0, $vr1, 1
vssrani.h.w	$vr0, $vr1, 1
vssrani.w.d	$vr0, $vr1, 1
vssrani.d.q	$vr0, $vr1, 1
vssrani.bu.h	$vr0, $vr1, 1
vssrani.hu.w	$vr0, $vr1, 1
vssrani.wu.d	$vr0, $vr1, 1
vssrani.du.q	$vr0, $vr1, 1
vssrarni.b.h	$vr0, $vr1, 1
vssrarni.h.w	$vr0, $vr1, 1
vssrarni.w.d	$vr0, $vr1, 1
vssrarni.d.q	$vr0, $vr1, 1
vssrarni.bu.h	$vr0, $vr1, 1
vssrarni.hu.w	$vr0, $vr1, 1
vssrarni.wu.d	$vr0, $vr1, 1
vssrarni.du.q	$vr0, $vr1, 1
vextrins.d	$vr0, $vr1, 1
vextrins.w	$vr0, $vr1, 1
vextrins.h	$vr0, $vr1, 1
vextrins.b	$vr0, $vr1, 1
vshuf4i.b	$vr0, $vr1, 1
vshuf4i.h	$vr0, $vr1, 1
vshuf4i.w	$vr0, $vr1, 1
vshuf4i.d	$vr0, $vr1, 1
vbitseli.b	$vr0, $vr1, 1
vandi.b	$vr0, $vr1, 1
vori.b	$vr0, $vr1, 1
vxori.b	$vr0, $vr1, 1
vnori.b	$vr0, $vr1, 1
vrepli.b	$vr0, 1
vaddwev.h.b	$vr0, $vr1, $vr2
vaddwev.w.h	$vr0, $vr1, $vr2
vaddwev.d.w	$vr0, $vr1, $vr2
vaddwev.q.d	$vr0, $vr1, $vr2
vaddwev.h.bu	$vr0, $vr1, $vr2
vaddwev.w.hu	$vr0, $vr1, $vr2
vaddwev.d.wu	$vr0, $vr1, $vr2
vaddwev.q.du	$vr0, $vr1, $vr2
vaddwev.h.bu.b	$vr0, $vr1, $vr2
vaddwev.w.hu.h	$vr0, $vr1, $vr2
vaddwev.d.wu.w	$vr0, $vr1, $vr2
vaddwev.q.du.d	$vr0, $vr1, $vr2
vaddwod.h.b	$vr0, $vr1, $vr2
vaddwod.w.h	$vr0, $vr1, $vr2
vaddwod.d.w	$vr0, $vr1, $vr2
vaddwod.q.d	$vr0, $vr1, $vr2
vaddwod.h.bu	$vr0, $vr1, $vr2
vaddwod.w.hu	$vr0, $vr1, $vr2
vaddwod.d.wu	$vr0, $vr1, $vr2
vaddwod.q.du	$vr0, $vr1, $vr2
vaddwod.h.bu.b	$vr0, $vr1, $vr2
vaddwod.w.hu.h	$vr0, $vr1, $vr2
vaddwod.d.wu.w	$vr0, $vr1, $vr2
vaddwod.q.du.d	$vr0, $vr1, $vr2
vmaddwev.h.b	$vr0, $vr1, $vr2
vmaddwev.w.h	$vr0, $vr1, $vr2
vmaddwev.d.w	$vr0, $vr1, $vr2
vmaddwev.q.d	$vr0, $vr1, $vr2
vmaddwev.h.bu	$vr0, $vr1, $vr2
vmaddwev.w.hu	$vr0, $vr1, $vr2
vmaddwev.d.wu	$vr0, $vr1, $vr2
vmaddwev.q.du	$vr0, $vr1, $vr2
vmaddwev.h.bu.b	$vr0, $vr1, $vr2
vmaddwev.w.hu.h	$vr0, $vr1, $vr2
vmaddwev.d.wu.w	$vr0, $vr1, $vr2
vmaddwev.q.du.d	$vr0, $vr1, $vr2
vmaddwod.h.b	$vr0, $vr1, $vr2
vmaddwod.w.h	$vr0, $vr1, $vr2
vmaddwod.d.w	$vr0, $vr1, $vr2
vmaddwod.q.d	$vr0, $vr1, $vr2
vmaddwod.h.bu	$vr0, $vr1, $vr2
vmaddwod.w.hu	$vr0, $vr1, $vr2
vmaddwod.d.wu	$vr0, $vr1, $vr2
vmaddwod.q.du	$vr0, $vr1, $vr2
vmaddwod.h.bu.b	$vr0, $vr1, $vr2
vmaddwod.w.hu.h	$vr0, $vr1, $vr2
vmaddwod.d.wu.w	$vr0, $vr1, $vr2
vmaddwod.q.du.d	$vr0, $vr1, $vr2
vmulwev.h.b	$vr0, $vr1, $vr2
vmulwev.w.h	$vr0, $vr1, $vr2
vmulwev.d.w	$vr0, $vr1, $vr2
vmulwev.q.d	$vr0, $vr1, $vr2
vmulwev.h.bu	$vr0, $vr1, $vr2
vmulwev.w.hu	$vr0, $vr1, $vr2
vmulwev.d.wu	$vr0, $vr1, $vr2
vmulwev.q.du	$vr0, $vr1, $vr2
vmulwev.h.bu.b	$vr0, $vr1, $vr2
vmulwev.w.hu.h	$vr0, $vr1, $vr2
vmulwev.d.wu.w	$vr0, $vr1, $vr2
vmulwev.q.du.d	$vr0, $vr1, $vr2
vmulwod.h.b	$vr0, $vr1, $vr2
vmulwod.w.h	$vr0, $vr1, $vr2
vmulwod.d.w	$vr0, $vr1, $vr2
vmulwod.q.d	$vr0, $vr1, $vr2
vmulwod.h.bu	$vr0, $vr1, $vr2
vmulwod.w.hu	$vr0, $vr1, $vr2
vmulwod.d.wu	$vr0, $vr1, $vr2
vmulwod.q.du	$vr0, $vr1, $vr2
vmulwod.h.bu.b	$vr0, $vr1, $vr2
vmulwod.w.hu.h	$vr0, $vr1, $vr2
vmulwod.d.wu.w	$vr0, $vr1, $vr2
vmulwod.q.du.d	$vr0, $vr1, $vr2
vsubwev.h.b	$vr0, $vr1, $vr2
vsubwev.w.h	$vr0, $vr1, $vr2
vsubwev.d.w	$vr0, $vr1, $vr2
vsubwev.q.d	$vr0, $vr1, $vr2
vsubwev.h.bu	$vr0, $vr1, $vr2
vsubwev.w.hu	$vr0, $vr1, $vr2
vsubwev.d.wu	$vr0, $vr1, $vr2
vsubwev.q.du	$vr0, $vr1, $vr2
vsubwod.h.b	$vr0, $vr1, $vr2
vsubwod.w.h	$vr0, $vr1, $vr2
vsubwod.d.w	$vr0, $vr1, $vr2
vsubwod.q.d	$vr0, $vr1, $vr2
vsubwod.h.bu	$vr0, $vr1, $vr2
vsubwod.w.hu	$vr0, $vr1, $vr2
vsubwod.d.wu	$vr0, $vr1, $vr2
vsubwod.q.du	$vr0, $vr1, $vr2
vrepli.d	$vr0, 1
vrepli.h	$vr0, 1
vrepli.w	$vr0, 1
vldi	$vr0, 1
vpermi.w	$vr0, $vr1, 1
xvseq.b	$xr0, $xr1, $xr2
xvseq.h	$xr0, $xr1, $xr2
xvseq.w	$xr0, $xr1, $xr2
xvseq.d	$xr0, $xr1, $xr2
xvsle.b	$xr0, $xr1, $xr2
xvsle.h	$xr0, $xr1, $xr2
xvsle.w	$xr0, $xr1, $xr2
xvsle.d	$xr0, $xr1, $xr2
xvsle.bu	$xr0, $xr1, $xr2
xvsle.hu	$xr0, $xr1, $xr2
xvsle.wu	$xr0, $xr1, $xr2
xvsle.du	$xr0, $xr1, $xr2
xvslt.b	$xr0, $xr1, $xr2
xvslt.h	$xr0, $xr1, $xr2
xvslt.w	$xr0, $xr1, $xr2
xvslt.d	$xr0, $xr1, $xr2
xvslt.bu	$xr0, $xr1, $xr2
xvslt.hu	$xr0, $xr1, $xr2
xvslt.wu	$xr0, $xr1, $xr2
xvslt.du	$xr0, $xr1, $xr2
xvadd.b	$xr0, $xr1, $xr2
xvadd.h	$xr0, $xr1, $xr2
xvadd.w	$xr0, $xr1, $xr2
xvadd.d	$xr0, $xr1, $xr2
xvsub.b	$xr0, $xr1, $xr2
xvsub.h	$xr0, $xr1, $xr2
xvsub.w	$xr0, $xr1, $xr2
xvsub.d	$xr0, $xr1, $xr2
xvsadd.b	$xr0, $xr1, $xr2
xvsadd.h	$xr0, $xr1, $xr2
xvsadd.w	$xr0, $xr1, $xr2
xvsadd.d	$xr0, $xr1, $xr2
xvssub.b	$xr0, $xr1, $xr2
xvssub.h	$xr0, $xr1, $xr2
xvssub.w	$xr0, $xr1, $xr2
xvssub.d	$xr0, $xr1, $xr2
xvsadd.bu	$xr0, $xr1, $xr2
xvsadd.hu	$xr0, $xr1, $xr2
xvsadd.wu	$xr0, $xr1, $xr2
xvsadd.du	$xr0, $xr1, $xr2
xvssub.bu	$xr0, $xr1, $xr2
xvssub.hu	$xr0, $xr1, $xr2
xvssub.wu	$xr0, $xr1, $xr2
xvssub.du	$xr0, $xr1, $xr2
xvhaddw.h.b	$xr0, $xr1, $xr2
xvhaddw.w.h	$xr0, $xr1, $xr2
xvhaddw.d.w	$xr0, $xr1, $xr2
xvhaddw.q.d	$xr0, $xr1, $xr2
xvhsubw.h.b	$xr0, $xr1, $xr2
xvhsubw.w.h	$xr0, $xr1, $xr2
xvhsubw.d.w	$xr0, $xr1, $xr2
xvhsubw.q.d	$xr0, $xr1, $xr2
xvhaddw.hu.bu	$xr0, $xr1, $xr2
xvhaddw.wu.hu	$xr0, $xr1, $xr2
xvhaddw.du.wu	$xr0, $xr1, $xr2
xvhaddw.qu.du	$xr0, $xr1, $xr2
xvhsubw.hu.bu	$xr0, $xr1, $xr2
xvhsubw.wu.hu	$xr0, $xr1, $xr2
xvhsubw.du.wu	$xr0, $xr1, $xr2
xvhsubw.qu.du	$xr0, $xr1, $xr2
xvaddwev.h.b	$xr0, $xr1, $xr2
xvaddwev.w.h	$xr0, $xr1, $xr2
xvaddwev.d.w	$xr0, $xr1, $xr2
xvaddwev.q.d	$xr0, $xr1, $xr2
xvaddwev.h.bu	$xr0, $xr1, $xr2
xvaddwev.w.hu	$xr0, $xr1, $xr2
xvaddwev.d.wu	$xr0, $xr1, $xr2
xvaddwev.q.du	$xr0, $xr1, $xr2
xvaddwev.h.bu.b	$xr0, $xr1, $xr2
xvaddwev.w.hu.h	$xr0, $xr1, $xr2
xvaddwev.d.wu.w	$xr0, $xr1, $xr2
xvaddwev.q.du.d	$xr0, $xr1, $xr2
xvaddwod.h.b	$xr0, $xr1, $xr2
xvaddwod.w.h	$xr0, $xr1, $xr2
xvaddwod.d.w	$xr0, $xr1, $xr2
xvaddwod.q.d	$xr0, $xr1, $xr2
xvaddwod.h.bu	$xr0, $xr1, $xr2
xvaddwod.w.hu	$xr0, $xr1, $xr2
xvaddwod.d.wu	$xr0, $xr1, $xr2
xvaddwod.q.du	$xr0, $xr1, $xr2
xvaddwod.h.bu.b	$xr0, $xr1, $xr2
xvaddwod.w.hu.h	$xr0, $xr1, $xr2
xvaddwod.d.wu.w	$xr0, $xr1, $xr2
xvaddwod.q.du.d	$xr0, $xr1, $xr2
xvmaddwev.h.b	$xr0, $xr1, $xr2
xvmaddwev.w.h	$xr0, $xr1, $xr2
xvmaddwev.d.w	$xr0, $xr1, $xr2
xvmaddwev.q.d	$xr0, $xr1, $xr2
xvmaddwev.h.bu.b	$xr0, $xr1, $xr2
xvmaddwev.w.hu.h	$xr0, $xr1, $xr2
xvmaddwev.d.wu.w	$xr0, $xr1, $xr2
xvmaddwev.q.du.d	$xr0, $xr1, $xr2
xvmaddwev.h.bu	$xr0, $xr1, $xr2
xvmaddwev.w.hu	$xr0, $xr1, $xr2
xvmaddwev.d.wu	$xr0, $xr1, $xr2
xvmaddwev.q.du	$xr0, $xr1, $xr2
xvmaddwod.h.b	$xr0, $xr1, $xr2
xvmaddwod.w.h	$xr0, $xr1, $xr2
xvmaddwod.d.w	$xr0, $xr1, $xr2
xvmaddwod.q.d	$xr0, $xr1, $xr2
xvmaddwod.h.bu	$xr0, $xr1, $xr2
xvmaddwod.w.hu	$xr0, $xr1, $xr2
xvmaddwod.d.wu	$xr0, $xr1, $xr2
xvmaddwod.q.du	$xr0, $xr1, $xr2
xvmaddwod.h.bu.b	$xr0, $xr1, $xr2
xvmaddwod.w.hu.h	$xr0, $xr1, $xr2
xvmaddwod.d.wu.w	$xr0, $xr1, $xr2
xvmaddwod.q.du.d	$xr0, $xr1, $xr2
xvmulwev.h.b	$xr0, $xr1, $xr2
xvmulwev.w.h	$xr0, $xr1, $xr2
xvmulwev.d.w	$xr0, $xr1, $xr2
xvmulwev.q.d	$xr0, $xr1, $xr2
xvmulwev.h.bu	$xr0, $xr1, $xr2
xvmulwev.w.hu	$xr0, $xr1, $xr2
xvmulwev.d.wu	$xr0, $xr1, $xr2
xvmulwev.q.du	$xr0, $xr1, $xr2
xvmulwev.h.bu.b	$xr0, $xr1, $xr2
xvmulwev.w.hu.h	$xr0, $xr1, $xr2
xvmulwev.d.wu.w	$xr0, $xr1, $xr2
xvmulwev.q.du.d	$xr0, $xr1, $xr2
xvmulwod.h.b	$xr0, $xr1, $xr2
xvmulwod.w.h	$xr0, $xr1, $xr2
xvmulwod.d.w	$xr0, $xr1, $xr2
xvmulwod.q.d	$xr0, $xr1, $xr2
xvmulwod.h.bu	$xr0, $xr1, $xr2
xvmulwod.w.hu	$xr0, $xr1, $xr2
xvmulwod.d.wu	$xr0, $xr1, $xr2
xvmulwod.q.du	$xr0, $xr1, $xr2
xvmulwod.h.bu.b	$xr0, $xr1, $xr2
xvmulwod.w.hu.h	$xr0, $xr1, $xr2
xvmulwod.d.wu.w	$xr0, $xr1, $xr2
xvmulwod.q.du.d	$xr0, $xr1, $xr2
xvsubwev.h.b	$xr0, $xr1, $xr2
xvsubwev.w.h	$xr0, $xr1, $xr2
xvsubwev.d.w	$xr0, $xr1, $xr2
xvsubwev.q.d	$xr0, $xr1, $xr2
xvsubwev.h.bu	$xr0, $xr1, $xr2
xvsubwev.w.hu	$xr0, $xr1, $xr2
xvsubwev.d.wu	$xr0, $xr1, $xr2
xvsubwev.q.du	$xr0, $xr1, $xr2
xvsubwod.h.b	$xr0, $xr1, $xr2
xvsubwod.w.h	$xr0, $xr1, $xr2
xvsubwod.d.w	$xr0, $xr1, $xr2
xvsubwod.q.d	$xr0, $xr1, $xr2
xvsubwod.h.bu	$xr0, $xr1, $xr2
xvsubwod.w.hu	$xr0, $xr1, $xr2
xvsubwod.d.wu	$xr0, $xr1, $xr2
xvsubwod.q.du	$xr0, $xr1, $xr2
xvadda.b	$xr0, $xr1, $xr2
xvadda.h	$xr0, $xr1, $xr2
xvadda.w	$xr0, $xr1, $xr2
xvadda.d	$xr0, $xr1, $xr2
xvabsd.b	$xr0, $xr1, $xr2
xvabsd.h	$xr0, $xr1, $xr2
xvabsd.w	$xr0, $xr1, $xr2
xvabsd.d	$xr0, $xr1, $xr2
xvabsd.bu	$xr0, $xr1, $xr2
xvabsd.hu	$xr0, $xr1, $xr2
xvabsd.wu	$xr0, $xr1, $xr2
xvabsd.du	$xr0, $xr1, $xr2
xvavg.b	$xr0, $xr1, $xr2
xvavg.h	$xr0, $xr1, $xr2
xvavg.w	$xr0, $xr1, $xr2
xvavg.d	$xr0, $xr1, $xr2
xvavg.bu	$xr0, $xr1, $xr2
xvavg.hu	$xr0, $xr1, $xr2
xvavg.wu	$xr0, $xr1, $xr2
xvavg.du	$xr0, $xr1, $xr2
xvavgr.b	$xr0, $xr1, $xr2
xvavgr.h	$xr0, $xr1, $xr2
xvavgr.w	$xr0, $xr1, $xr2
xvavgr.d	$xr0, $xr1, $xr2
xvavgr.bu	$xr0, $xr1, $xr2
xvavgr.hu	$xr0, $xr1, $xr2
xvavgr.wu	$xr0, $xr1, $xr2
xvavgr.du	$xr0, $xr1, $xr2
xvmax.b	$xr0, $xr1, $xr2
xvmax.h	$xr0, $xr1, $xr2
xvmax.w	$xr0, $xr1, $xr2
xvmax.d	$xr0, $xr1, $xr2
xvmin.b	$xr0, $xr1, $xr2
xvmin.h	$xr0, $xr1, $xr2
xvmin.w	$xr0, $xr1, $xr2
xvmin.d	$xr0, $xr1, $xr2
xvmax.bu	$xr0, $xr1, $xr2
xvmax.hu	$xr0, $xr1, $xr2
xvmax.wu	$xr0, $xr1, $xr2
xvmax.du	$xr0, $xr1, $xr2
xvmin.bu	$xr0, $xr1, $xr2
xvmin.hu	$xr0, $xr1, $xr2
xvmin.wu	$xr0, $xr1, $xr2
xvmin.du	$xr0, $xr1, $xr2
xvmul.b	$xr0, $xr1, $xr2
xvmul.h	$xr0, $xr1, $xr2
xvmul.w	$xr0, $xr1, $xr2
xvmul.d	$xr0, $xr1, $xr2
xvmuh.b	$xr0, $xr1, $xr2
xvmuh.h	$xr0, $xr1, $xr2
xvmuh.w	$xr0, $xr1, $xr2
xvmuh.d	$xr0, $xr1, $xr2
xvmuh.bu	$xr0, $xr1, $xr2
xvmuh.hu	$xr0, $xr1, $xr2
xvmuh.wu	$xr0, $xr1, $xr2
xvmuh.du	$xr0, $xr1, $xr2
xvmadd.b	$xr0, $xr1, $xr2
xvmadd.h	$xr0, $xr1, $xr2
xvmadd.w	$xr0, $xr1, $xr2
xvmadd.d	$xr0, $xr1, $xr2
xvmsub.b	$xr0, $xr1, $xr2
xvmsub.h	$xr0, $xr1, $xr2
xvmsub.w	$xr0, $xr1, $xr2
xvmsub.d	$xr0, $xr1, $xr2
xvdiv.b	$xr0, $xr1, $xr2
xvdiv.h	$xr0, $xr1, $xr2
xvdiv.w	$xr0, $xr1, $xr2
xvdiv.d	$xr0, $xr1, $xr2
xvmod.b	$xr0, $xr1, $xr2
xvmod.h	$xr0, $xr1, $xr2
xvmod.w	$xr0, $xr1, $xr2
xvmod.d	$xr0, $xr1, $xr2
xvdiv.bu	$xr0, $xr1, $xr2
xvdiv.hu	$xr0, $xr1, $xr2
xvdiv.wu	$xr0, $xr1, $xr2
xvdiv.du	$xr0, $xr1, $xr2
xvmod.bu	$xr0, $xr1, $xr2
xvmod.hu	$xr0, $xr1, $xr2
xvmod.wu	$xr0, $xr1, $xr2
xvmod.du	$xr0, $xr1, $xr2
xvsll.b	$xr0, $xr1, $xr2
xvsll.h	$xr0, $xr1, $xr2
xvsll.w	$xr0, $xr1, $xr2
xvsll.d	$xr0, $xr1, $xr2
xvsrl.b	$xr0, $xr1, $xr2
xvsrl.h	$xr0, $xr1, $xr2
xvsrl.w	$xr0, $xr1, $xr2
xvsrl.d	$xr0, $xr1, $xr2
xvsra.b	$xr0, $xr1, $xr2
xvsra.h	$xr0, $xr1, $xr2
xvsra.w	$xr0, $xr1, $xr2
xvsra.d	$xr0, $xr1, $xr2
xvrotr.b	$xr0, $xr1, $xr2
xvrotr.h	$xr0, $xr1, $xr2
xvrotr.w	$xr0, $xr1, $xr2
xvrotr.d	$xr0, $xr1, $xr2
xvsrlr.b	$xr0, $xr1, $xr2
xvsrlr.h	$xr0, $xr1, $xr2
xvsrlr.w	$xr0, $xr1, $xr2
xvsrlr.d	$xr0, $xr1, $xr2
xvsrar.b	$xr0, $xr1, $xr2
xvsrar.h	$xr0, $xr1, $xr2
xvsrar.w	$xr0, $xr1, $xr2
xvsrar.d	$xr0, $xr1, $xr2
xvsrln.b.h	$xr0, $xr1, $xr2
xvsrln.h.w	$xr0, $xr1, $xr2
xvsrln.w.d	$xr0, $xr1, $xr2
xvsran.b.h	$xr0, $xr1, $xr2
xvsran.h.w	$xr0, $xr1, $xr2
xvsran.w.d	$xr0, $xr1, $xr2
xvsrlrn.b.h	$xr0, $xr1, $xr2
xvsrlrn.h.w	$xr0, $xr1, $xr2
xvsrlrn.w.d	$xr0, $xr1, $xr2
xvsrarn.b.h	$xr0, $xr1, $xr2
xvsrarn.h.w	$xr0, $xr1, $xr2
xvsrarn.w.d	$xr0, $xr1, $xr2
xvssrln.b.h	$xr0, $xr1, $xr2
xvssrln.h.w	$xr0, $xr1, $xr2
xvssrln.w.d	$xr0, $xr1, $xr2
xvssran.b.h	$xr0, $xr1, $xr2
xvssran.h.w	$xr0, $xr1, $xr2
xvssran.w.d	$xr0, $xr1, $xr2
xvssrlrn.b.h	$xr0, $xr1, $xr2
xvssrlrn.h.w	$xr0, $xr1, $xr2
xvssrlrn.w.d	$xr0, $xr1, $xr2
xvssrarn.b.h	$xr0, $xr1, $xr2
xvssrarn.h.w	$xr0, $xr1, $xr2
xvssrarn.w.d	$xr0, $xr1, $xr2
xvssrln.bu.h	$xr0, $xr1, $xr2
xvssrln.hu.w	$xr0, $xr1, $xr2
xvssrln.wu.d	$xr0, $xr1, $xr2
xvssran.bu.h	$xr0, $xr1, $xr2
xvssran.hu.w	$xr0, $xr1, $xr2
xvssran.wu.d	$xr0, $xr1, $xr2
xvssrlrn.bu.h	$xr0, $xr1, $xr2
xvssrlrn.hu.w	$xr0, $xr1, $xr2
xvssrlrn.wu.d	$xr0, $xr1, $xr2
xvssrarn.bu.h	$xr0, $xr1, $xr2
xvssrarn.hu.w	$xr0, $xr1, $xr2
xvssrarn.wu.d	$xr0, $xr1, $xr2
xvbitclr.b	$xr0, $xr1, $xr2
xvbitclr.h	$xr0, $xr1, $xr2
xvbitclr.w	$xr0, $xr1, $xr2
xvbitclr.d	$xr0, $xr1, $xr2
xvbitset.b	$xr0, $xr1, $xr2
xvbitset.h	$xr0, $xr1, $xr2
xvbitset.w	$xr0, $xr1, $xr2
xvbitset.d	$xr0, $xr1, $xr2
xvbitrev.b	$xr0, $xr1, $xr2
xvbitrev.h	$xr0, $xr1, $xr2
xvbitrev.w	$xr0, $xr1, $xr2
xvbitrev.d	$xr0, $xr1, $xr2
xvpackev.b	$xr0, $xr1, $xr2
xvpackev.h	$xr0, $xr1, $xr2
xvpackev.w	$xr0, $xr1, $xr2
xvpackev.d	$xr0, $xr1, $xr2
xvpackod.b	$xr0, $xr1, $xr2
xvpackod.h	$xr0, $xr1, $xr2
xvpackod.w	$xr0, $xr1, $xr2
xvpackod.d	$xr0, $xr1, $xr2
xvilvl.b	$xr0, $xr1, $xr2
xvilvl.h	$xr0, $xr1, $xr2
xvilvl.w	$xr0, $xr1, $xr2
xvilvl.d	$xr0, $xr1, $xr2
xvilvh.b	$xr0, $xr1, $xr2
xvilvh.h	$xr0, $xr1, $xr2
xvilvh.w	$xr0, $xr1, $xr2
xvilvh.d	$xr0, $xr1, $xr2
xvpickev.b	$xr0, $xr1, $xr2
xvpickev.h	$xr0, $xr1, $xr2
xvpickev.w	$xr0, $xr1, $xr2
xvpickev.d	$xr0, $xr1, $xr2
xvpickod.b	$xr0, $xr1, $xr2
xvpickod.h	$xr0, $xr1, $xr2
xvpickod.w	$xr0, $xr1, $xr2
xvpickod.d	$xr0, $xr1, $xr2
xvreplve.b	$xr0, $xr1, $r2
xvreplve.h	$xr0, $xr1, $r2
xvreplve.w	$xr0, $xr1, $r2
xvreplve.d	$xr0, $xr1, $r2
xvand.v	$xr0, $xr1, $xr2
xvor.v	$xr0, $xr1, $xr2
xvxor.v	$xr0, $xr1, $xr2
xvnor.v	$xr0, $xr1, $xr2
xvandn.v	$xr0, $xr1, $xr2
xvorn.v	$xr0, $xr1, $xr2
xvfrstp.b	$xr0, $xr1, $xr2
xvfrstp.h	$xr0, $xr1, $xr2
xvadd.q	$xr0, $xr1, $xr2
xvsub.q	$xr0, $xr1, $xr2
xvsigncov.b	$xr0, $xr1, $xr2
xvsigncov.h	$xr0, $xr1, $xr2
xvsigncov.w	$xr0, $xr1, $xr2
xvsigncov.d	$xr0, $xr1, $xr2
xvfadd.s	$xr0, $xr1, $xr2
xvfadd.d	$xr0, $xr1, $xr2
xvfsub.s	$xr0, $xr1, $xr2
xvfsub.d	$xr0, $xr1, $xr2
xvfmul.s	$xr0, $xr1, $xr2
xvfmul.d	$xr0, $xr1, $xr2
xvfdiv.s	$xr0, $xr1, $xr2
xvfdiv.d	$xr0, $xr1, $xr2
xvfmax.s	$xr0, $xr1, $xr2
xvfmax.d	$xr0, $xr1, $xr2
xvfmin.s	$xr0, $xr1, $xr2
xvfmin.d	$xr0, $xr1, $xr2
xvfmaxa.s	$xr0, $xr1, $xr2
xvfmaxa.d	$xr0, $xr1, $xr2
xvfmina.s	$xr0, $xr1, $xr2
xvfmina.d	$xr0, $xr1, $xr2
xvfcvt.h.s	$xr0, $xr1, $xr2
xvfcvt.s.d	$xr0, $xr1, $xr2
xvffint.s.l	$xr0, $xr1, $xr2
xvftint.w.d	$xr0, $xr1, $xr2
xvftintrm.w.d	$xr0, $xr1, $xr2
xvftintrp.w.d	$xr0, $xr1, $xr2
xvftintrz.w.d	$xr0, $xr1, $xr2
xvftintrne.w.d	$xr0, $xr1, $xr2
xvshuf.h	$xr0, $xr1, $xr2
xvshuf.w	$xr0, $xr1, $xr2
xvshuf.d	$xr0, $xr1, $xr2
xvperm.w	$xr0, $xr1, $xr2
xvseqi.b	$xr0, $xr1, 1
xvseqi.h	$xr0, $xr1, 1
xvseqi.w	$xr0, $xr1, 1
xvseqi.d	$xr0, $xr1, 1
xvslei.b	$xr0, $xr1, 1
xvslei.h	$xr0, $xr1, 1
xvslei.w	$xr0, $xr1, 1
xvslei.d	$xr0, $xr1, 1
xvslei.bu	$xr0, $xr1, 1
xvslei.hu	$xr0, $xr1, 1
xvslei.wu	$xr0, $xr1, 1
xvslei.du	$xr0, $xr1, 1
xvslti.b	$xr0, $xr1, 1
xvslti.h	$xr0, $xr1, 1
xvslti.w	$xr0, $xr1, 1
xvslti.d	$xr0, $xr1, 1
xvslti.bu	$xr0, $xr1, 1
xvslti.hu	$xr0, $xr1, 1
xvslti.wu	$xr0, $xr1, 1
xvslti.du	$xr0, $xr1, 1
xvaddi.bu	$xr0, $xr1, 1
xvaddi.hu	$xr0, $xr1, 1
xvaddi.wu	$xr0, $xr1, 1
xvaddi.du	$xr0, $xr1, 1
xvsubi.bu	$xr0, $xr1, 1
xvsubi.hu	$xr0, $xr1, 1
xvsubi.wu	$xr0, $xr1, 1
xvsubi.du	$xr0, $xr1, 1
xvbsll.v	$xr0, $xr1, 1
xvbsrl.v	$xr0, $xr1, 1
xvmaxi.b	$xr0, $xr1, 1
xvmaxi.h	$xr0, $xr1, 1
xvmaxi.w	$xr0, $xr1, 1
xvmaxi.d	$xr0, $xr1, 1
xvmini.b	$xr0, $xr1, 1
xvmini.h	$xr0, $xr1, 1
xvmini.w	$xr0, $xr1, 1
xvmini.d	$xr0, $xr1, 1
xvmaxi.bu	$xr0, $xr1, 1
xvmaxi.hu	$xr0, $xr1, 1
xvmaxi.wu	$xr0, $xr1, 1
xvmaxi.du	$xr0, $xr1, 1
xvmini.bu	$xr0, $xr1, 1
xvmini.hu	$xr0, $xr1, 1
xvmini.wu	$xr0, $xr1, 1
xvmini.du	$xr0, $xr1, 1
xvfrstpi.b	$xr0, $xr1, 1
xvfrstpi.h	$xr0, $xr1, 1
xvclo.b	$xr0, $xr1
xvclo.h	$xr0, $xr1
xvclo.w	$xr0, $xr1
xvclo.d	$xr0, $xr1
xvclz.b	$xr0, $xr1
xvclz.h	$xr0, $xr1
xvclz.w	$xr0, $xr1
xvclz.d	$xr0, $xr1
xvpcnt.b	$xr0, $xr1
xvpcnt.h	$xr0, $xr1
xvpcnt.w	$xr0, $xr1
xvpcnt.d	$xr0, $xr1
xvneg.b	$xr0, $xr1
xvneg.h	$xr0, $xr1
xvneg.w	$xr0, $xr1
xvneg.d	$xr0, $xr1
xvmskltz.b	$xr0, $xr1
xvmskltz.h	$xr0, $xr1
xvmskltz.w	$xr0, $xr1
xvmskltz.d	$xr0, $xr1
xvmskgez.b	$xr0, $xr1
xvmsknz.b	$xr0, $xr1
xvseteqz.v	$fcc0, $xr1
xvsetnez.v	$fcc0, $xr1
xvsetanyeqz.b	$fcc0, $xr1
xvsetanyeqz.h	$fcc0, $xr1
xvsetanyeqz.w	$fcc0, $xr1
xvsetanyeqz.d	$fcc0, $xr1
xvsetallnez.b	$fcc0, $xr1
xvsetallnez.h	$fcc0, $xr1
xvsetallnez.w	$fcc0, $xr1
xvsetallnez.d	$fcc0, $xr1
xvflogb.s	$xr0, $xr1
xvflogb.d	$xr0, $xr1
xvfclass.s	$xr0, $xr1
xvfclass.d	$xr0, $xr1
xvfsqrt.s	$xr0, $xr1
xvfsqrt.d	$xr0, $xr1
xvfrecip.s	$xr0, $xr1
xvfrecip.d	$xr0, $xr1
xvfrsqrt.s	$xr0, $xr1
xvfrsqrt.d	$xr0, $xr1
xvfrint.s	$xr0, $xr1
xvfrint.d	$xr0, $xr1
xvfrintrm.s	$xr0, $xr1
xvfrintrm.d	$xr0, $xr1
xvfrintrp.s	$xr0, $xr1
xvfrintrp.d	$xr0, $xr1
xvfrintrz.s	$xr0, $xr1
xvfrintrz.d	$xr0, $xr1
xvfrintrne.s	$xr0, $xr1
xvfrintrne.d	$xr0, $xr1
xvfcvtl.s.h	$xr0, $xr1
xvfcvth.s.h	$xr0, $xr1
xvfcvtl.d.s	$xr0, $xr1
xvfcvth.d.s	$xr0, $xr1
xvffint.s.w	$xr0, $xr1
xvffint.s.wu	$xr0, $xr1
xvffint.d.l	$xr0, $xr1
xvffint.d.lu	$xr0, $xr1
xvffintl.d.w	$xr0, $xr1
xvffinth.d.w	$xr0, $xr1
xvftint.w.s	$xr0, $xr1
xvftint.l.d	$xr0, $xr1
xvftintrm.w.s	$xr0, $xr1
xvftintrm.l.d	$xr0, $xr1
xvftintrp.w.s	$xr0, $xr1
xvftintrp.l.d	$xr0, $xr1
xvftintrz.w.s	$xr0, $xr1
xvftintrz.l.d	$xr0, $xr1
xvftintrne.w.s	$xr0, $xr1
xvftintrne.l.d	$xr0, $xr1
xvftint.wu.s	$xr0, $xr1
xvftint.lu.d	$xr0, $xr1
xvftintrz.wu.s	$xr0, $xr1
xvftintrz.lu.d	$xr0, $xr1
xvftintl.l.s	$xr0, $xr1
xvftinth.l.s	$xr0, $xr1
xvftintrml.l.s	$xr0, $xr1
xvftintrmh.l.s	$xr0, $xr1
xvftintrpl.l.s	$xr0, $xr1
xvftintrph.l.s	$xr0, $xr1
xvftintrzl.l.s	$xr0, $xr1
xvftintrzh.l.s	$xr0, $xr1
xvftintrnel.l.s	$xr0, $xr1
xvftintrneh.l.s	$xr0, $xr1
xvexth.h.b	$xr0, $xr1
xvexth.w.h	$xr0, $xr1
xvexth.d.w	$xr0, $xr1
xvexth.q.d	$xr0, $xr1
xvexth.hu.bu	$xr0, $xr1
xvexth.wu.hu	$xr0, $xr1
xvexth.du.wu	$xr0, $xr1
xvexth.qu.du	$xr0, $xr1
xvreplgr2vr.b	$xr0, $r1
xvreplgr2vr.h	$xr0, $r1
xvreplgr2vr.w	$xr0, $r1
xvreplgr2vr.d	$xr0, $r1
vext2xv.h.b	$xr0, $xr1
vext2xv.w.b	$xr0, $xr1
vext2xv.d.b	$xr0, $xr1
vext2xv.w.h	$xr0, $xr1
vext2xv.d.h	$xr0, $xr1
vext2xv.d.w	$xr0, $xr1
vext2xv.hu.bu	$xr0, $xr1
vext2xv.wu.bu	$xr0, $xr1
vext2xv.du.bu	$xr0, $xr1
vext2xv.wu.hu	$xr0, $xr1
vext2xv.du.hu	$xr0, $xr1
vext2xv.du.wu	$xr0, $xr1
xvhseli.d	$xr0, $xr1, 1
xvrotri.b	$xr0, $xr1, 1
xvrotri.h	$xr0, $xr1, 1
xvrotri.w	$xr0, $xr1, 1
xvrotri.d	$xr0, $xr1, 1
xvsrlri.b	$xr0, $xr1, 1
xvsrlri.h	$xr0, $xr1, 1
xvsrlri.w	$xr0, $xr1, 1
xvsrlri.d	$xr0, $xr1, 1
xvsrari.b	$xr0, $xr1, 1
xvsrari.h	$xr0, $xr1, 1
xvsrari.w	$xr0, $xr1, 1
xvsrari.d	$xr0, $xr1, 1
xvinsgr2vr.w	$xr0, $r1, 1
xvinsgr2vr.d	$xr0, $r1, 1
xvpickve2gr.w	$r0, $xr1, 1
xvpickve2gr.d	$r0, $xr1, 1
xvpickve2gr.wu	$r0, $xr1, 1
xvpickve2gr.du	$r0, $xr1, 1
xvrepl128vei.b	$xr0, $xr1, 1
xvrepl128vei.h	$xr0, $xr1, 1
xvrepl128vei.w	$xr0, $xr1, 1
xvrepl128vei.d	$xr0, $xr1, 1
xvinsve0.w	$xr0, $xr1, 1
xvinsve0.d	$xr0, $xr1, 1
xvpickve.w	$xr0, $xr1, 1
xvpickve.d	$xr0, $xr1, 1
xvreplve0.b	$xr0, $xr1
xvreplve0.h	$xr0, $xr1
xvreplve0.w	$xr0, $xr1
xvreplve0.d	$xr0, $xr1
xvreplve0.q	$xr0, $xr1
xvsllwil.h.b	$xr0, $xr1, 1
xvsllwil.w.h	$xr0, $xr1, 1
xvsllwil.d.w	$xr0, $xr1, 1
xvextl.q.d	$xr0, $xr1
xvsllwil.hu.bu	$xr0, $xr1, 1
xvsllwil.wu.hu	$xr0, $xr1, 1
xvsllwil.du.wu	$xr0, $xr1, 1
xvextl.qu.du	$xr0, $xr1
xvbitclri.b	$xr0, $xr1, 1
xvbitclri.h	$xr0, $xr1, 1
xvbitclri.w	$xr0, $xr1, 1
xvbitclri.d	$xr0, $xr1, 1
xvbitseti.b	$xr0, $xr1, 1
xvbitseti.h	$xr0, $xr1, 1
xvbitseti.w	$xr0, $xr1, 1
xvbitseti.d	$xr0, $xr1, 1
xvbitrevi.b	$xr0, $xr1, 1
xvbitrevi.h	$xr0, $xr1, 1
xvbitrevi.w	$xr0, $xr1, 1
xvbitrevi.d	$xr0, $xr1, 1
xvsat.b	$xr0, $xr1, 1
xvsat.h	$xr0, $xr1, 1
xvsat.w	$xr0, $xr1, 1
xvsat.d	$xr0, $xr1, 1
xvsat.bu	$xr0, $xr1, 1
xvsat.hu	$xr0, $xr1, 1
xvsat.wu	$xr0, $xr1, 1
xvsat.du	$xr0, $xr1, 1
xvslli.b	$xr0, $xr1, 1
xvslli.h	$xr0, $xr1, 1
xvslli.w	$xr0, $xr1, 1
xvslli.d	$xr0, $xr1, 1
xvsrli.b	$xr0, $xr1, 1
xvsrli.h	$xr0, $xr1, 1
xvsrli.w	$xr0, $xr1, 1
xvsrli.d	$xr0, $xr1, 1
xvsrai.b	$xr0, $xr1, 1
xvsrai.h	$xr0, $xr1, 1
xvsrai.w	$xr0, $xr1, 1
xvsrai.d	$xr0, $xr1, 1
xvsrlni.b.h	$xr0, $xr1, 1
xvsrlni.h.w	$xr0, $xr1, 1
xvsrlni.w.d	$xr0, $xr1, 1
xvsrlni.d.q	$xr0, $xr1, 1
xvsrlrni.b.h	$xr0, $xr1, 1
xvsrlrni.h.w	$xr0, $xr1, 1
xvsrlrni.w.d	$xr0, $xr1, 1
xvsrlrni.d.q	$xr0, $xr1, 1
xvssrlni.b.h	$xr0, $xr1, 1
xvssrlni.h.w	$xr0, $xr1, 1
xvssrlni.w.d	$xr0, $xr1, 1
xvssrlni.d.q	$xr0, $xr1, 1
xvssrlni.bu.h	$xr0, $xr1, 1
xvssrlni.hu.w	$xr0, $xr1, 1
xvssrlni.wu.d	$xr0, $xr1, 1
xvssrlni.du.q	$xr0, $xr1, 1
xvssrlrni.b.h	$xr0, $xr1, 1
xvssrlrni.h.w	$xr0, $xr1, 1
xvssrlrni.w.d	$xr0, $xr1, 1
xvssrlrni.d.q	$xr0, $xr1, 1
xvssrlrni.bu.h	$xr0, $xr1, 1
xvssrlrni.hu.w	$xr0, $xr1, 1
xvssrlrni.wu.d	$xr0, $xr1, 1
xvssrlrni.du.q	$xr0, $xr1, 1
xvsrani.b.h	$xr0, $xr1, 1
xvsrani.h.w	$xr0, $xr1, 1
xvsrani.w.d	$xr0, $xr1, 1
xvsrani.d.q	$xr0, $xr1, 1
xvsrarni.b.h	$xr0, $xr1, 1
xvsrarni.h.w	$xr0, $xr1, 1
xvsrarni.w.d	$xr0, $xr1, 1
xvsrarni.d.q	$xr0, $xr1, 1
xvssrani.b.h	$xr0, $xr1, 1
xvssrani.h.w	$xr0, $xr1, 1
xvssrani.w.d	$xr0, $xr1, 1
xvssrani.d.q	$xr0, $xr1, 1
xvssrani.bu.h	$xr0, $xr1, 1
xvssrani.hu.w	$xr0, $xr1, 1
xvssrani.wu.d	$xr0, $xr1, 1
xvssrani.du.q	$xr0, $xr1, 1
xvssrarni.b.h	$xr0, $xr1, 1
xvssrarni.h.w	$xr0, $xr1, 1
xvssrarni.w.d	$xr0, $xr1, 1
xvssrarni.d.q	$xr0, $xr1, 1
xvssrarni.bu.h	$xr0, $xr1, 1
xvssrarni.hu.w	$xr0, $xr1, 1
xvssrarni.wu.d	$xr0, $xr1, 1
xvssrarni.du.q	$xr0, $xr1, 1
xvextrins.d	$xr0, $xr1, 1
xvextrins.w	$xr0, $xr1, 1
xvextrins.h	$xr0, $xr1, 1
xvextrins.b	$xr0, $xr1, 1
xvshuf4i.b	$xr0, $xr1, 1
xvshuf4i.h	$xr0, $xr1, 1
xvshuf4i.w	$xr0, $xr1, 1
xvshuf4i.d	$xr0, $xr1, 1
xvbitseli.b	$xr0, $xr1, 1
xvandi.b	$xr0, $xr1, 1
xvori.b	$xr0, $xr1, 1
xvxori.b	$xr0, $xr1, 1
xvnori.b	$xr0, $xr1, 1
xvrepli.b	$xr0, 1
xvrepli.d	$xr0, 1
xvrepli.h	$xr0, 1
xvrepli.w	$xr0, 1
xvldi	$xr0, 1
xvpermi.w	$xr0, $xr1, 1
xvpermi.d	$xr0, $xr1, 1
xvpermi.q	$xr0, $xr1, 1
vfrecipe.s	$vr0, $vr1
vfrecipe.d	$vr0, $vr1
vfrsqrte.s	$vr0, $vr1
vfrsqrte.d	$vr0, $vr1
xvfrecipe.s	$xr0, $xr1
xvfrecipe.d	$xr0, $xr1
xvfrsqrte.s	$xr0, $xr1
xvfrsqrte.d	$xr0, $xr1
