.* Assembler messages:
.*:6: Error: invalid instruction suffix for `imulzu'
.*:7: Error: no such instruction: `imulzud \$0xa,%ebx,%eax'
.*:8: Error: operand size mismatch for `imulzu'
.*:9: Error: invalid instruction suffix for `imulzu'
.*:10: Error: no such instruction: `imulzud \$0xaaaa,%ebx,%eax'
.*:11: Error: operand size mismatch for `imulzu'
.*:12: Error: operand size mismatch for `imulzu'
.*:13: Error: operand size mismatch for `imulzu'
.*:14: Error: can't encode register '%ah' in an instruction requiring EVEX prefix
.*:15: Error: operand size mismatch for `setzub'
.*:16: Error: operand size mismatch for `setzuae'
.*:17: Error: operand size mismatch for `setzue'
.*:18: Error: operand size mismatch for `setzune'
.*:19: Error: operand size mismatch for `setzube'
.*:20: Error: operand size mismatch for `setzua'
.*:21: Error: operand size mismatch for `setzus'
.*:22: Error: operand size mismatch for `setzuns'
.*:23: Error: operand size mismatch for `setzup'
.*:24: Error: operand size mismatch for `setzunp'
.*:25: Error: operand size mismatch for `setzul'
.*:26: Error: operand size mismatch for `setzuge'
.*:27: Error: operand size mismatch for `setzule'
.*:28: Error: operand size mismatch for `setzug'
#pass
