[^:]*: Assembler messages:
[^:]*:8: Error: SRS base register must be r13 -- `srsdb r4,#13'
[^:]*:9: Error: SRS base register must be r13 -- `srsia r4,#13'
[^:]*:16: Error: SRS base register must be r13 -- `srsea r4,#13'
[^:]*:17: Error: SRS base register must be r13 -- `srsfd r4,#13'
[^:]*:18: Error: SRS base register must be r13 -- `srs r4,#13'
