.*: Assembler messages:
.*:2: Warning: the `dsp' extension requires MIPS64 revision 2 or greater
.*:2: Warning: the `eva' extension requires MIPS64 revision 2 or greater
.*:2: Warning: the `mt' extension requires MIPS64 revision 2 or greater
