.*: Assembler messages:
.*: Error: illegal operands `th.sfence.vmas'
.*: Error: illegal operands `th.sync a0'
.*: Error: illegal operands `th.sync.i a0'
.*: Error: illegal operands `th.sync.is a0'
.*: Error: illegal operands `th.sync.s a0'
