target:

	# cm.mva01s
	cm.mva01s s0,s7
	cm.mva01s s0,s6
	cm.mva01s s1,s7
	cm.mva01s s1,s6
	cm.mva01s s7,s3
	cm.mva01s x19,s0
	cm.mva01s s5,x20
	cm.mva01s x21,x22

	# cm.mvsa01
	cm.mvsa01 s7,s0
	cm.mvsa01 s6,s0
	cm.mvsa01 s7,s1
	cm.mvsa01 s6,s1
	cm.mvsa01 s3,s7
	cm.mvsa01 x19,s0
	cm.mvsa01 s5,x20
	cm.mvsa01 x21,x22
