	jalr 	$32
	jalr	$31
	jalr	$7, $7
	jalr	$31, $2
	jalr	$0
	jalr	$0, $31
	jalr	$31, $0

	.set	mips32
	jalr.hb	$32
	jalr.hb	$31
	jalr.hb	$7, $7
	jalr.hb	$31, $2
	jalr.hb	$0
	jalr.hb	$0, $31
	jalr.hb	$31, $0
