.*: Assembler messages:
.*: Warning: specified register cannot be written to at operand 1 -- `msr id_dfr1_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr id_mmfr5_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr id_isar6_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr icc_iar0_el1,x1'
.*: Warning: specified register cannot be read from at operand 2 -- `mrs x0,icc_eoir0_el1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr icc_hppir0_el1,x1'
.*: Warning: specified register cannot be read from at operand 2 -- `mrs x0,icc_dir_el1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr icc_rpr_el1,x1'
.*: Warning: specified register cannot be read from at operand 2 -- `mrs x0,icc_sgi1r_el1'
.*: Warning: specified register cannot be read from at operand 2 -- `mrs x0,icc_asgi1r_el1'
.*: Warning: specified register cannot be read from at operand 2 -- `mrs x0,icc_sgi0r_el1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr icc_iar1_el1,x1'
.*: Warning: specified register cannot be read from at operand 2 -- `mrs x0,icc_eoir1_el1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr icc_hppir1_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr ich_misr_el2,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr ich_eisr_el2,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr ich_elrsr_el2,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr lorid_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr ccsidr2_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr pmmir_el1,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amcfgr_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amcgcr_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amevtyper00_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amevtyper01_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amevtyper02_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amevtyper03_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr amcg1idr_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr cntpctss_el0,x1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr cntvctss_el0,x1'
