#source: attr-gnu-abi-msa-1.s
#readelf: -A
#name: MIPS gnu_attribute Tag_GNU_MIPS_ABI_MSA,1

Attribute Section: gnu
File Attributes
  Tag_GNU_MIPS_ABI_FP: Hard float \(double precision\)
  Tag_GNU_MIPS_ABI_MSA: 128-bit MSA

#...
