[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: Error: bad instruction `vdot\.b16 d0,d0,d0'
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vmmla q0\.b16,q0,q0'
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: Error: bad instruction `vdot\.bf32 d0,d0,d0\[1\]'
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vdot d0\.bf32,d0,d0'
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vdot d0\.bf32,d0\.bf16,d0\.bf16'
[^ :]+:[0-9]+: Error: operand types can't be inferred -- `vdotne d0,d0,d0'
[^ :]+:[0-9]+: Error: operand types can't be inferred -- `vdotne d0,d0,d0\[1\]'
[^ :]+:[0-9]+: Error: operand types can't be inferred -- `vmmlane q0,q0,q0'
[^ :]+:[0-9]+: Error: thumb conditional instruction should be in IT block -- `vfmatne\.bf16 q0,d0,d0'
[^ :]+:[0-9]+: Error: thumb conditional instruction should be in IT block -- `vfmatne\.bf16 q0,d0,d0\[0\]'
[^ :]+:[0-9]+: Error: thumb conditional instruction should be in IT block -- `vfmabne\.bf16 q0,d0,d0'
[^ :]+:[0-9]+: Error: thumb conditional instruction should be in IT block -- `vfmabne\.bf16 q0,d0,d0\[0\]'
[^ :]+:[0-9]+: Error: thumb conditional instruction should be in IT block -- `vcvtne\.bf16\.f32 d0,q0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot d32,d0,d0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot d0,d32,d0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot d0,d0,d32'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot d32,d0,d0\[0\]'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot d0,d32,d0\[0\]'
[^ :]+:[0-9]+: Error: indexed register must be less than 16 -- `vdot d0,d0,d16\[0\]'
[^ :]+:[0-9]+: Error: VFP single, double or Neon quad precision register expected -- `vcvtne\.bf16\.f32 d32,q0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot q16,q0,q0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot q0,q16,q0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot q0,q0,q16'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot q16,q0,d0\[0\]'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vdot q0,q16,d0\[0\]'
[^ :]+:[0-9]+: Error: Neon quad precision register expected -- `vmmla q16,q0,q0'
[^ :]+:[0-9]+: Error: Neon quad precision register expected -- `vmmla q0,q16,q0'
[^ :]+:[0-9]+: Error: Neon quad precision register expected -- `vmmla q0,q0,q16'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vfmab\.bf16 q16,d0,d0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vfmab\.bf16 q16,d0,d0\[0\]'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vfmab\.bf16 q0,q32,d0'
[^ :]+:[0-9]+: Error: Neon double or quad precision register expected -- `vfmab\.bf16 q0,q32,d0\[0\]'
[^ :]+:[0-9]+: Error: indexed register must be less than 8 -- `vfmab\.bf16 q0,q0,d8\[0\]'
[^ :]+:[0-9]+: Error: VFP single, double or Neon quad precision register expected -- `vfmat\.bf16 q16,d0,d0'
[^ :]+:[0-9]+: Error: VFP single, double or Neon quad precision register expected -- `vfmat\.bf16 q16,d0,d0\[0\]'
[^ :]+:[0-9]+: Error: VFP single, double or Neon quad precision register expected -- `vfmat\.bf16 q0,q32,d0'
[^ :]+:[0-9]+: Error: VFP single, double or Neon quad precision register expected -- `vfmat\.bf16 q0,q32,d0\[0\]'
[^ :]+:[0-9]+: Error: indexed register must be less than 8 -- `vfmat\.bf16 q0,q0,d8\[0\]'
[^ :]+:[0-9]+: Error: VFP single, double or Neon quad precision register expected -- `vcvt\.bf16\.f32 d0,q16'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vdot q0,q0,d5'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vdot q0,d5,q0'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vdot d5,q0,q0'
[^ :]+:[0-9]+: Error: only D registers may be indexed -- `vdot q0,d5,q0\[0\]'
[^ :]+:[0-9]+: Error: only D registers may be indexed -- `vdot d5,q0,q0\[0\]'
[^ :]+:[0-9]+: Error: Neon quad precision register expected -- `vmmla q0,q0,d5'
[^ :]+:[0-9]+: Error: Neon quad precision register expected -- `vmmla q0,d5,q0'
[^ :]+:[0-9]+: Error: Neon quad precision register expected -- `vmmla d5,q0,q0'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vfmab\.bf16 d0,q0,d0'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vfmab\.bf16 d0,q0,d0\[0\]'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vfmat\.bf16 d0,q0,d0'
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vfmat\.bf16 d0,q0,d0\[0\]'
[^ :]+:[0-9]+: Error: operand size must match register width
[^ :]+:[0-9]+: Error: invalid neon suffix for non neon instruction
[^ :]+:[0-9]+: Error: index must be 0 or 1 -- `vdot q0,q0,d0\[2\]'
[^ :]+:[0-9]+: Error: index must be in the range 0 to 3 -- `vfmab\.bf16 q0,d0,d0\[4\]'
[^ :]+:[0-9]+: Error: index must be in the range 0 to 3 -- `vfmat\.bf16 q0,d0,d0\[4\]'
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad instruction `vcvtb\.b16\.f32 s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad instruction `vcvtb\.bf32\.f32 s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvtb s0\.b16,s0\.f32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvtb s0\.bf32,s0\.f32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad type in SIMD instruction -- `vcvtb s0\.f32,s0\.bf16'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad instruction `vcvtt\.b16\.f32 s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad instruction `vcvtt\.bf32\.f32 s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvtt s0\.b16,s0\.f32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvtt s0\.bf32,s0\.f32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad type in SIMD instruction -- `vcvtt s0\.f32,s0\.bf16'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad instruction `vcvt\.b16\.f32 d0,q0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad instruction `vcvt\.bf32\.f32 d0,q0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: unexpected type character `b' -- did you mean `bf'\?
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvt d0\.b16,q0\.f32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad size 32 in type specifier
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvt d0\.bf32,q0\.f32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad type in SIMD instruction -- `vcvt d0\.f32,q0\.bf16'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: immediate value out of range -- `vcvtt\.bf16\.f32 s0,s0,#0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vcvtt\.bf16\.f32 s0,s0,#1'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad type in SIMD instruction -- `vcvtt\.bf16\.f32 d0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvtt\.bf16\.f32 s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: constant expression required -- `vcvtt\.bf16\.f32 s0,s0,s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: constant expression required -- `vcvtt\.bf16\.f32 s0,s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: VFP single or double precision register expected -- `vcvtt\.bf16\.f32 s0,s32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: VFP single or double precision register expected -- `vcvtt\.bf16\.f32 s32,s32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: immediate value out of range -- `vcvtb\.bf16\.f32 s0,s0,#0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: invalid instruction shape -- `vcvtb\.bf16\.f32 s0,s0,#1'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad type in SIMD instruction -- `vcvtb\.bf16\.f32 d0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: bad arguments to instruction -- `vcvtb\.bf16\.f32 s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: constant expression required -- `vcvtb\.bf16\.f32 s0,s0,s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: constant expression required -- `vcvtb\.bf16\.f32 s0,s0,s0'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: VFP single or double precision register expected -- `vcvtb\.bf16\.f32 s0,s32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: VFP single or double precision register expected -- `vcvtb\.bf16\.f32 s32,s32'
[^ :]+:[0-9]+: *Info: macro .*
[^ :]+:[0-9]+: Error: instruction not allowed in IT block -- `vdotne\.bf16 d0,d20,d11'
[^ :]+:[0-9]+: Error: instruction not allowed in IT block -- `vdotne\.bf16 d0,d20,d11\[1\]'
[^ :]+:[0-9]+: Error: instruction not allowed in IT block -- `vmmlane\.bf16 q0,q0,q0'
[^ :]+:[0-9]+: Error: instruction not allowed in IT block -- `vdot\.bf16 d0,d20,d11'
[^ :]+:[0-9]+: Error: instruction not allowed in IT block -- `vdot\.bf16 d0,d20,d11\[1\]'
[^ :]+:[0-9]+: Error: instruction not allowed in IT block -- `vmmla\.bf16 q0,q0,q0'

