.*: Assembler messages:
.*:4: Error: PC-relative reference to a different section
.*:5: Error: PC-relative reference to a different section
.*:6: Error: PC-relative reference to a different section
.*:9: Error: PC-relative reference to a different section
.*:10: Error: PC-relative reference to a different section
.*:11: Error: PC-relative reference to a different section
