	# rd and rs2 must be even
	amocas.d	a1, a0, (a0)
	amocas.d	a0, a1, (a0)
	amocas.d.aq	a1, a0, (a0)
	amocas.d.aq	a0, a1, (a0)
	amocas.d.rl	a1, a0, (a0)
	amocas.d.rl	a0, a1, (a0)
	amocas.d.aqrl	a1, a0, (a0)
	amocas.d.aqrl	a0, a1, (a0)
	amocas.q	a1, a0, (a0)
	amocas.q	a0, a1, (a0)
	amocas.q.aq	a1, a0, (a0)
	amocas.q.aq	a0, a1, (a0)
	amocas.q.rl	a1, a0, (a0)
	amocas.q.rl	a0, a1, (a0)
	amocas.q.aqrl	a1, a0, (a0)
	amocas.q.aqrl	a0, a1, (a0)
