.*: Assembler messages:
.*:3: Error: @GOTTPOFF operator cannot be used with `kmovq'
.*:4: Error: @TLSLD operator cannot be used with `kmovq'
.*:7: Error: @TLSGD operator cannot be used with `add'
.*:8: Error: @TLSGD operator requires `%rdi' as dest register
.*:9: Error: @TLSGD operator requires `%rip' as base register
.*:10: Error: @TLSGD operator requires base register
.*:11: Error: @TLSGD operator requires `%rip' as base register
.*:12: Error: @TLSGD operator requires `%rdi' as dest register
.*:15: Error: @TLSLD operator cannot be used with `add'
.*:16: Error: @TLSLD operator requires `%rdi' as dest register
.*:17: Error: @TLSLD operator requires `%rip' as base register
.*:18: Error: @TLSLD operator requires base register
.*:19: Error: @TLSLD operator requires `%rip' as base register
.*:20: Error: @TLSLD operator requires `%rdi' as dest register
.*:23: Error: @TLSDESC operator cannot be used with `add'
.*:24: Error: @TLSDESC operator requires `%rip' as base register
.*:25: Error: @TLSDESC operator requires `%rip' as base register
.*:26: Error: @TLSDESC operator requires 64-bit dest register
.*:27: Error: @TLSDESC operator requires 64-bit dest register
.*:30: Error: @GOTTPOFF operator cannot be used with `sub'
.*:31: Error: @GOTTPOFF operator cannot be used with `xor'
.*:32: Error: @GOTTPOFF operator requires `%rip' as base register
.*:33: Error: @GOTTPOFF operator requires `%rip' as base register
.*:34: Error: @GOTTPOFF operator requires 64-bit dest register
.*:35: Error: @GOTTPOFF operator can be used with `add', but format is wrong
.*:36: Error: @GOTTPOFF operator can be used with `add', but format is wrong
.*:37: Error: @GOTTPOFF operator can be used with `add', but format is wrong
.*:38: Error: @GOTTPOFF operator can be used with `add', but format is wrong
.*:39: Error: @GOTTPOFF operator requires `%rip' as base register
.*:40: Error: @GOTTPOFF operator can be used with `mov', but format is wrong
.*:41: Error: @GOTTPOFF operator can be used with `mov', but format is wrong
.*:42: Error: @GOTTPOFF operator can be used with `mov', but format is wrong
.*:43: Error: @GOTTPOFF operator can be used with `mov', but format is wrong
.*:44: Error: @GOTTPOFF operator can be used with `mov', but format is wrong
.*:48: Error: @TLSCALL operator cannot be used with `lea'
.*:49: Error: @TLSCALL operator requires `%eax/%rax' as base register
.*:49: Error: 0-byte relocation cannot be applied to 4-byte field
.*:50: Error: `\*foo@tlscall\(%ax\)' is not a valid base/index expression
