fmopa za0.h, p0/m, p0/m, z0.b, z0.b
fmopa za1.h, p0/m, p0/m, z0.b, z0.b
fmopa za0.h, p7/m, p0/m, z0.b, z0.b
fmopa za0.h, p0/m, p7/m, z0.b, z0.b
fmopa za0.h, p0/m, p0/m, z31.b, z0.b
fmopa za0.h, p0/m, p0/m, z0.b, z31.b
