.*: Assembler messages:
.*: Error: register element index out of range 0 to 15 at operand 2 -- `dupq z0.b,z0.b\[16\]'
.*: Error: operand mismatch -- `dupq z0.h,z0.b\[16\]'
.*: Info:    did you mean this\?
.*: Info:    	dupq z0.b, z0.b\[16\]
.*: Info:    other valid variant\(s\):
.*: Info:    	dupq z0.h, z0.h\[16\]
.*: Info:    	dupq z0.s, z0.s\[16\]
.*: Info:    	dupq z0.d, z0.d\[16\]
.*: Error: operand mismatch -- `dupq z0.h,z0.s\[16\]'
.*: Info:    did you mean this\?
.*: Info:    	dupq z0.h, z0.h\[16\]
.*: Info:    other valid variant\(s\):
.*: Info:    	dupq z0.b, z0.b\[16\]
.*: Info:    	dupq z0.s, z0.s\[16\]
.*: Info:    	dupq z0.d, z0.d\[16\]
.*: Error: operand mismatch -- `dupq z0.s,z0.d\[16\]'
.*: Info:    did you mean this\?
.*: Info:    	dupq z0.s, z0.s\[16\]
.*: Info:    other valid variant\(s\):
.*: Info:    	dupq z0.b, z0.b\[16\]
.*: Info:    	dupq z0.h, z0.h\[16\]
.*: Info:    	dupq z0.d, z0.d\[16\]
.*: Error: register element index out of range 0 to 7 at operand 2 -- `dupq z0.h,z0.h\[8\]'
.*: Error: register element index out of range 0 to 3 at operand 2 -- `dupq z0.s,z0.s\[4\]'
.*: Error: register element index out of range 0 to 1 at operand 2 -- `dupq z0.d,z0.d\[2\]'
.*: Error: operand mismatch -- `dupq z0.q,z0.d\[16\]'
.*: Info:    did you mean this\?
.*: Info:    	dupq z0.d, z0.d\[16\]
.*: Info:    other valid variant\(s\):
.*: Info:    	dupq z0.b, z0.b\[16\]
.*: Info:    	dupq z0.h, z0.h\[16\]
.*: Info:    	dupq z0.s, z0.s\[16\]
.*: Error: operand mismatch -- `dupq z0.s,z0.q\[16\]'
.*: Info:    did you mean this\?
.*: Info:    	dupq z0.s, z0.s\[16\]
.*: Info:    other valid variant\(s\):
.*: Info:    	dupq z0.b, z0.b\[16\]
.*: Info:    	dupq z0.h, z0.h\[16\]
.*: Info:    	dupq z0.d, z0.d\[16\]
.*: Error: operand mismatch -- `dupq z10.q,z20.q\[0\]'
.*: Info:    did you mean this\?
.*: Info:    	dupq z10.b, z20.b\[0\]
.*: Info:    other valid variant\(s\):
.*: Info:    	dupq z10.h, z20.h\[0\]
.*: Info:    	dupq z10.s, z20.s\[0\]
.*: Info:    	dupq z10.d, z20.d\[0\]
