/* Copyright 2018-2024 Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include <stdint.h>

uint64_t caller (void);

static void
break_here_c (uint64_t value)
{
}

__attribute__((target("arm")))
uint64_t
caller_trampoline (void)
{
  return caller ();
}

int
main (void)
{
  uint64_t value = caller_trampoline ();
  break_here_c (value);
  return 0;
}
