[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w10,2\],{ ?z14\.h ?- ?z15\.h ?},z13\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w9,1\],{ ?z4\.h ?- ?z7\.h ?},z10\.h\[2\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},Z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},Z0\.H'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.h,z0\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.h ?- ?z0\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z15\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w9,3\],{ ?z21\.h ?- ?z22\.h ?},z9\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},Z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},Z0\.H'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.h,z31\.h,z0\.h,z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.h,z0\.h,z1\.h,z2\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.h ?- ?z2\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z15\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w10,5\],{ ?z17\.h ?- ?z20\.h ?},z3\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},{ ?Z0\.h ?- ?Z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},{ ?Z0\.H ?- ?Z1\.H ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},{ ?z30\.h ?- ?z31\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w10,1\],{ ?z22\.h ?- ?z23\.h ?},{ ?z18\.h ?- ?z19\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},{ ?Z0\.h ?- ?Z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},{ ?Z0\.H ?- ?Z3\.H ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},{ ?z28\.h ?- ?z31\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,3\],{ ?z16\.h ?- ?z19\.h ?},{ ?z24\.h ?- ?z27\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w10,2\],{ ?z14\.b ?- ?z15\.b ?},z13\.b\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w9,1\],{ ?z4\.b ?- ?z7\.b ?},z10\.b\[2\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},Z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},Z0\.B'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.b,z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w9,3\],{ ?z21\.b ?- ?z22\.b ?},z9\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.b,z31\.b,z0\.b,z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.b,z0\.b,z1\.b,z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z31\.b ?- ?z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w10,5\],{ ?z17\.b ?- ?z20\.b ?},z3\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},{ ?Z0\.b ?- ?Z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},{ ?Z0\.B ?- ?Z1\.B ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},{ ?z30\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w10,1\],{ ?z22\.b ?- ?z23\.b ?},{ ?z18\.b ?- ?z19\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},{ ?Z0\.b ?- ?Z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},{ ?Z0\.B ?- ?Z3\.B ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},{ ?z28\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sdot za\.s\[w11,3\],{ ?z16\.b ?- ?z19\.b ?},{ ?z24\.b ?- ?z27\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w10,2\],{ ?z14\.h ?- ?z15\.h ?},z13\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w9,1\],{ ?z4\.h ?- ?z7\.h ?},z10\.h\[2\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},Z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},Z0\.H'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.h,z0\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.h ?- ?z0\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z15\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w9,3\],{ ?z21\.h ?- ?z22\.h ?},z9\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},Z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},Z0\.H'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.h,z31\.h,z0\.h,z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.h,z0\.h,z1\.h,z2\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.h ?- ?z2\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z15\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w10,5\],{ ?z17\.h ?- ?z20\.h ?},z3\.h'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},{ ?Z0\.h ?- ?Z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},{ ?Z0\.H ?- ?Z1\.H ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},{ ?z30\.h ?- ?z31\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w10,1\],{ ?z22\.h ?- ?z23\.h ?},{ ?z18\.h ?- ?z19\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},{ ?Z0\.h ?- ?Z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},{ ?Z0\.H ?- ?Z3\.H ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},{ ?z28\.h ?- ?z31\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,3\],{ ?z16\.h ?- ?z19\.h ?},{ ?z24\.h ?- ?z27\.h ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w10,2\],{ ?z14\.b ?- ?z15\.b ?},z13\.b\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w9,1\],{ ?z4\.b ?- ?z7\.b ?},z10\.b\[2\]'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},Z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},Z0\.B'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.b,z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w9,3\],{ ?z21\.b ?- ?z22\.b ?},z9\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.b,z31\.b,z0\.b,z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.b,z0\.b,z1\.b,z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z31\.b ?- ?z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w10,5\],{ ?z17\.b ?- ?z20\.b ?},z3\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},{ ?Z0\.b ?- ?Z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},{ ?Z0\.B ?- ?Z1\.B ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},{ ?z30\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w10,1\],{ ?z22\.b ?- ?z23\.b ?},{ ?z18\.b ?- ?z19\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},{ ?Z0\.b ?- ?Z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},{ ?Z0\.B ?- ?Z3\.B ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},{ ?z28\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `udot za\.s\[w11,3\],{ ?z16\.b ?- ?z19\.b ?},{ ?z24\.b ?- ?z27\.b ?}'
