# name: attributes for -mcpu=arc600_mul64
# source: blank.s
# as: -mcpu=arc600_mul64
# readelf: -A

Attribute Section: ARC
File Attributes
  Tag_ARC_CPU_base: ARC6xx
  Tag_ARC_CPU_name: "arc600_mul64"
  Tag_ARC_ABI_osver: v4
  Tag_ARC_ATR_version: 1
