[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z0\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z31\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z0\.h,{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z19\.h,{ ?z14\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z0\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z31\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z0\.b,{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z11\.b,{ ?z20\.s ?- ?z23\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z0\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z31\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z0\.h,{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvt z22\.h,{ ?z4\.d ?- ?z7\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z0\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z31\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z0\.h,{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z19\.h,{ ?z14\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z0\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z31\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z0\.b,{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z11\.b,{ ?z20\.s ?- ?z23\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z0\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z31\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z0\.h,{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtu z22\.h,{ ?z4\.d ?- ?z7\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z0\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z31\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z0\.h,{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z19\.h,{ ?z14\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z0\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z31\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z0\.b,{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z11\.b,{ ?z20\.s ?- ?z23\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z0\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z31\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z0\.h,{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvt z22\.h,{ ?z4\.d ?- ?z7\.d ?}'
