/* ZERO (single-vector).  */
zero za.d[w8, 0, vgx2]
zero za.d[w11, 0, vgx2]
zero za.d[w8, 7, vgx2]
zero za.d[w11, 7, vgx2]
zero za.d[w9, 4, vgx2]
zero za.d[w10, 3, vgx2]

zero za.d[w8, 0, vgx4]
zero za.d[w11, 0, vgx4]
zero za.d[w8, 7, vgx4]
zero za.d[w11, 7, vgx4]
zero za.d[w9, 4, vgx4]
zero za.d[w10, 3, vgx4]

/* ZERO (double-vector).  */
zero za.d[w8, 0:1]
zero za.d[w11, 0:1]
zero za.d[w8, 14:15]
zero za.d[w11, 14:15]
zero za.d[w9, 2:3]
zero za.d[w10, 6:7]

zero za.d[w8, 0:1, vgx2]
zero za.d[w11, 0:1, vgx2]
zero za.d[w8, 6:7, vgx2]
zero za.d[w9, 2:3, vgx2]

zero za.d[w8, 0:1, vgx4]
zero za.d[w11, 0:1, vgx4]
zero za.d[w8, 6:7, vgx4]
zero za.d[w9, 2:3, vgx4]

/* ZERO (quad-vector).  */
zero za.d[w8, 0:3]
zero za.d[w11, 0:3]
zero za.d[w8, 8:11]
zero za.d[w11, 8:11]
zero za.d[w9, 4:7]
zero za.d[w10, 0:3]

zero za.d[w8, 0:3, vgx2]
zero za.d[w11, 0:3, vgx2]
zero za.d[w8, 4:7, vgx2]
zero za.d[w11, 4:7, vgx2]
zero za.d[w9, 0:3, vgx2]
zero za.d[w10, 4:7, vgx2]

zero za.d[w8, 0:3, vgx4]
zero za.d[w11, 0:3, vgx4]
zero za.d[w8, 4:7, vgx4]
zero za.d[w11, 4:7, vgx4]
zero za.d[w9, 0:3, vgx4]
zero za.d[w10, 4:7, vgx4]
