[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z31\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.h,{ ?z30\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.h,{ ?z0\.s ?- ?z1\.s ?},#16'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z1\.h,{ ?z26\.s ?- ?z27\.s ?},#14'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z0\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z31\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z0\.h,{ ?z30\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z0\.h,{ ?z0\.s ?- ?z1\.s ?},#16'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z15\.h,{ ?z6\.s ?- ?z7\.s ?},#9'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z31\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.h,{ ?z30\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.h,{ ?z0\.s ?- ?z1\.s ?},#16'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z18\.h,{ ?z2\.s ?- ?z3\.s ?},#6'
