.*: Assembler messages:
.*:15: Error: branch to misaligned address \(0x11a1\)
.*:17: Error: branch to misaligned address \(0x11a1\)
.*:19: Error: branch to misaligned address \(0x11a1\)
.*:21: Error: branch to misaligned address \(0x11a2\)
.*:23: Error: branch to misaligned address \(0x11a2\)
.*:25: Error: branch to misaligned address \(0x11a2\)
.*:27: Error: branch to misaligned address \(0x11a3\)
.*:29: Error: branch to misaligned address \(0x11a3\)
.*:31: Error: branch to misaligned address \(0x11a3\)
.*:39: Error: branch to misaligned address \(0x11a5\)
.*:41: Error: branch to misaligned address \(0x11a5\)
.*:43: Error: branch to misaligned address \(0x11a5\)
.*:45: Error: branch to misaligned address \(0x11a6\)
.*:47: Error: branch to misaligned address \(0x11a6\)
.*:49: Error: branch to misaligned address \(0x11a6\)
.*:51: Error: branch to misaligned address \(0x11a7\)
.*:53: Error: branch to misaligned address \(0x11a7\)
.*:55: Error: branch to misaligned address \(0x11a7\)
.*:65: Error: branch to a symbol in another ISA mode
.*:67: Error: branch to a symbol in another ISA mode
.*:69: Error: branch to misaligned address \(0x11b2\)
.*:71: Error: branch to a symbol in another ISA mode
.*:73: Error: branch to a symbol in another ISA mode
.*:77: Error: branch to a symbol in another ISA mode
.*:79: Error: branch to a symbol in another ISA mode
.*:81: Error: branch to misaligned address \(0x11b5\)
.*:83: Error: branch to a symbol in another ISA mode
.*:85: Error: branch to a symbol in another ISA mode
.*:87: Error: branch to misaligned address \(0x11b6\)
.*:89: Error: branch to a symbol in another ISA mode
.*:91: Error: branch to a symbol in another ISA mode
.*:93: Error: branch to misaligned address \(0x11b7\)
.*:95: Error: branch to a symbol in another ISA mode
.*:97: Error: branch to a symbol in another ISA mode
.*:101: Error: branch to a symbol in another ISA mode
.*:103: Error: branch to a symbol in another ISA mode
