[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: expected 'za' rather than a ZA tile at operand 1 -- `smlall za0\.d\[w8,0:3\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected 'za' rather than a ZA tile at operand 1 -- `smlall za0h\.d\[w8,0:3\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a selection register in the range w8-w11 at operand 1 -- `smlall za\.d\[w7,0:3\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a selection register in the range w8-w11 at operand 1 -- `smlall za\.d\[w12,0:3\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0:1\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0:2\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0,vgx4\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: unexpected vector group size at operand 1 -- `smlall za\.d\[w8,0:3,vgx2\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: unexpected vector group size at operand 1 -- `smlall za\.d\[w8,0:3,vgx4\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,1:4\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,2:5\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,3:6\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 12 at operand 1 -- `smlall za\.d\[w8,16:19\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Error: z0 ?- ?z15 expected at operand 3 -- `smlall za\.d\[w8,0:3\],z0\.h,z16\.h\[0\]'
[^ :]+:[0-9]+: Error: register element index out of range 0 to 7 at operand 3 -- `smlall za\.d\[w8,0:3\],z0\.h,z0\.h\[-1\]'
[^ :]+:[0-9]+: Error: register element index out of range 0 to 7 at operand 3 -- `smlall za\.d\[w8,0:3\],z0\.h,z0\.h\[8\]'
[^ :]+:[0-9]+: Error: operand mismatch -- `smlall za\.d\[w8,0:3\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	smlall za\.s\[w8, 0:3\], z0\.b, z0\.b\[0\]
[^ :]+:[0-9]+: Error: operand mismatch -- `smlall za\.d\[w8,0:3\],z0\.d,z0\.d\[0\]'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	smlall za\.d\[w8, 0:3\], z0\.h, z0\.h\[0\]
[^ :]+:[0-9]+: Error: expected a selection register in the range w8-w11 at operand 1 -- `smlall za\.d\[w7,0:3\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a selection register in the range w8-w11 at operand 1 -- `smlall za\.d\[w12,0:3\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0:1\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0:2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a list of 4 registers at operand 2 -- `smlall za\.d\[w8,0:3,vgx4\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,1:4\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,2:5\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,3:6\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 4 at operand 1 -- `smlall za\.d\[w8,8:11\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z1\.h ?- ?z2\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: z0 ?- ?z15 expected at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},z16\.h\[0\]'
[^ :]+:[0-9]+: Error: register element index out of range 0 to 7 at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[-1\]'
[^ :]+:[0-9]+: Error: register element index out of range 0 to 7 at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[8\]'
[^ :]+:[0-9]+: Error: expected a selection register in the range w8-w11 at operand 1 -- `smlall za\.d\[w7,0:3\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a selection register in the range w8-w11 at operand 1 -- `smlall za\.d\[w12,0:3\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0:1\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a range of four offsets at operand 1 -- `smlall za\.d\[w8,0:2\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: expected a list of 2 registers at operand 2 -- `smlall za\.d\[w8,0:3,vgx2\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,1:4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,2:5\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: starting offset is not a multiple of 4 at operand 1 -- `smlall za\.d\[w8,3:6\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 4 at operand 1 -- `smlall za\.d\[w8,8:11\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z1\.h ?- ?z4\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z2\.h ?- ?z5\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z3\.h ?- ?z6\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: z0 ?- ?z15 expected at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},z16\.h\[0\]'
[^ :]+:[0-9]+: Error: register element index out of range 0 to 7 at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[-1\]'
[^ :]+:[0-9]+: Error: register element index out of range 0 to 7 at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[8\]'
[^ :]+:[0-9]+: Error: unexpected vector group size at operand 1 -- `smlall za\.d\[w8,0:3,vgx2\],z0\.h,z0\.h'
[^ :]+:[0-9]+: Error: unexpected vector group size at operand 1 -- `smlall za\.d\[w8,0:3,vgx4\],z0\.h,z0\.h'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 12 at operand 1 -- `smlall za\.d\[w8,16:19\],z0\.h,z0\.h'
[^ :]+:[0-9]+: Error: z0 ?- ?z15 expected at operand 3 -- `smlall za\.d\[w8,0:3\],z0\.h,z16\.h'
[^ :]+:[0-9]+: Error: expected a list of 4 registers at operand 2 -- `smlall za\.d\[w8,0:3,vgx4\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 4 at operand 1 -- `smlall za\.d\[w8,8:11\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: expected a list of 2 or 4 registers at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z2\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: z0 ?- ?z15 expected at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},z16\.h'
[^ :]+:[0-9]+: Error: expected a list of 2 registers at operand 2 -- `smlall za\.d\[w8,0:3,vgx2\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 4 at operand 1 -- `smlall za\.d\[w8,8:11\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Error: z0 ?- ?z15 expected at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},z16\.h'
[^ :]+:[0-9]+: Error: expected a list of 4 registers at operand 2 -- `smlall za\.d\[w8,0:3,vgx4\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 4 at operand 1 -- `smlall za\.d\[w8,8:11\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z1\.h ?- ?z2\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},{ ?z1\.h ?- ?z2\.h ?}'
[^ :]+:[0-9]+: Error: expected a list of 2 registers at operand 2 -- `smlall za\.d\[w8,0:3,vgx2\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: immediate offset out of range 0 to 4 at operand 1 -- `smlall za\.d\[w8,8:11\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z1\.h ?- ?z4\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z2\.h ?- ?z5\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 2 -- `smlall za\.d\[w8,0:3\],{ ?z3\.h ?- ?z6\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},{ ?z1\.h ?- ?z4\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},{ ?z2\.h ?- ?z5\.h ?}'
[^ :]+:[0-9]+: Error: start register out of range at operand 3 -- `smlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},{ ?z3\.h ?- ?z6\.h ?}'
[^ :]+:[0-9]+: Error: operand mismatch -- `sumlall za\.d\[w8,0:3\],z0\.h,z0\.h\[0\]'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	sumlall za\.s\[w8, 0:3\], z0\.b, z0\.b\[0\]
[^ :]+:[0-9]+: Error: operand mismatch -- `sumlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	sumlall za\.s\[w8, 0:3\], {z0\.b-z1\.b}, z0\.b\[0\]
[^ :]+:[0-9]+: Error: operand mismatch -- `sumlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	sumlall za\.s\[w8, 0:3\], {z0\.b-z3\.b}, z0\.b\[0\]
[^ :]+:[0-9]+: Error: operand 3 must be an indexed SVE vector register -- `sumlall za\.d\[w8,0:3\],z0\.h,z0\.h'
[^ :]+:[0-9]+: Error: operand mismatch -- `sumlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},z0\.h'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	sumlall za\.s\[w8, 0:3\], {z0\.b-z1\.b}, z0\.b
[^ :]+:[0-9]+: Error: operand mismatch -- `sumlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},z0\.h'
[^ :]+:[0-9]+: Info:    did you mean this\?
[^ :]+:[0-9]+: Info:    	sumlall za\.s\[w8, 0:3\], {z0\.b-z3\.b}, z0\.b
[^ :]+:[0-9]+: Error: expected an SVE vector register at operand 3 -- `sumlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z1\.h ?},{ ?z0\.h ?- ?z1\.h ?}'
[^ :]+:[0-9]+: Error: expected an SVE vector register at operand 3 -- `sumlall za\.d\[w8,0:3\],{ ?z0\.h ?- ?z3\.h ?},{ ?z0\.h ?- ?z3\.h ?}'
