[^:]*: Assembler messages:
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r0'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r0'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r0'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r1'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r1'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r1'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r2'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r2'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r2'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r4'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r4'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r4'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r7'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r7'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r7'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r8'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r8'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r8'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r10'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r10'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r10'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r12'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r12'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r12'
[^:]*:7: Error: syntax error -- `vldrb.s8 q0,r14'
[^:]*:8: Error: syntax error -- `vldrb.u8 q0,r14'
[^:]*:9: Error: syntax error -- `vstrb.8 q0,r14'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r0'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r0'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r0'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r1'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r1'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r1'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r2'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r2'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r2'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r4'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r4'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r4'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r7'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r7'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r7'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r8'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r8'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r8'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r10'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r10'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r10'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r12'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r12'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r12'
[^:]*:7: Error: syntax error -- `vldrb.s8 q1,r14'
[^:]*:8: Error: syntax error -- `vldrb.u8 q1,r14'
[^:]*:9: Error: syntax error -- `vstrb.8 q1,r14'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r0'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r0'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r0'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r1'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r1'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r1'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r2'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r2'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r2'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r4'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r4'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r4'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r7'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r7'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r7'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r8'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r8'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r8'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r10'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r10'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r10'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r12'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r12'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r12'
[^:]*:7: Error: syntax error -- `vldrb.s8 q2,r14'
[^:]*:8: Error: syntax error -- `vldrb.u8 q2,r14'
[^:]*:9: Error: syntax error -- `vstrb.8 q2,r14'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r0'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r0'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r0'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r1'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r1'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r1'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r2'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r2'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r2'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r4'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r4'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r4'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r7'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r7'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r7'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r8'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r8'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r8'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r10'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r10'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r10'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r12'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r12'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r12'
[^:]*:7: Error: syntax error -- `vldrb.s8 q4,r14'
[^:]*:8: Error: syntax error -- `vldrb.u8 q4,r14'
[^:]*:9: Error: syntax error -- `vstrb.8 q4,r14'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r0'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r0'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r0'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r1'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r1'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r1'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r2'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r2'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r2'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r4'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r4'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r4'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r7'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r7'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r7'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r8'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r8'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r8'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r10'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r10'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r10'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r12'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r12'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r12'
[^:]*:7: Error: syntax error -- `vldrb.s8 q7,r14'
[^:]*:8: Error: syntax error -- `vldrb.u8 q7,r14'
[^:]*:9: Error: syntax error -- `vstrb.8 q7,r14'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r0'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r0'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r0'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r1'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r1'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r1'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r2'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r2'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r2'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r4'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r4'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r4'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r7'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r7'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r7'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r8'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r8'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r8'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r10'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r10'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r10'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r12'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r12'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r12'
[^:]*:7: Error: syntax error -- `vldrb.s16 q0,r14'
[^:]*:8: Error: syntax error -- `vldrb.u16 q0,r14'
[^:]*:9: Error: syntax error -- `vstrb.16 q0,r14'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r0'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r0'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r0'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r1'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r1'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r1'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r2'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r2'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r2'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r4'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r4'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r4'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r7'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r7'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r7'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r8'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r8'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r8'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r10'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r10'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r10'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r12'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r12'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r12'
[^:]*:7: Error: syntax error -- `vldrb.s16 q1,r14'
[^:]*:8: Error: syntax error -- `vldrb.u16 q1,r14'
[^:]*:9: Error: syntax error -- `vstrb.16 q1,r14'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r0'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r0'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r0'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r1'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r1'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r1'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r2'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r2'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r2'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r4'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r4'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r4'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r7'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r7'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r7'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r8'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r8'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r8'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r10'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r10'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r10'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r12'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r12'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r12'
[^:]*:7: Error: syntax error -- `vldrb.s16 q2,r14'
[^:]*:8: Error: syntax error -- `vldrb.u16 q2,r14'
[^:]*:9: Error: syntax error -- `vstrb.16 q2,r14'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r0'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r0'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r0'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r1'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r1'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r1'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r2'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r2'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r2'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r4'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r4'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r4'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r7'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r7'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r7'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r8'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r8'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r8'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r10'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r10'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r10'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r12'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r12'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r12'
[^:]*:7: Error: syntax error -- `vldrb.s16 q4,r14'
[^:]*:8: Error: syntax error -- `vldrb.u16 q4,r14'
[^:]*:9: Error: syntax error -- `vstrb.16 q4,r14'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r0'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r0'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r0'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r1'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r1'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r1'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r2'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r2'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r2'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r4'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r4'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r4'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r7'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r7'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r7'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r8'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r8'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r8'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r10'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r10'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r10'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r12'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r12'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r12'
[^:]*:7: Error: syntax error -- `vldrb.s16 q7,r14'
[^:]*:8: Error: syntax error -- `vldrb.u16 q7,r14'
[^:]*:9: Error: syntax error -- `vstrb.16 q7,r14'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r0'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r0'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r0'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r1'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r1'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r1'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r2'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r2'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r2'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r4'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r4'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r4'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r7'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r7'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r7'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r8'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r8'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r8'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r10'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r10'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r10'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r12'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r12'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r12'
[^:]*:7: Error: syntax error -- `vldrb.s32 q0,r14'
[^:]*:8: Error: syntax error -- `vldrb.u32 q0,r14'
[^:]*:9: Error: syntax error -- `vstrb.32 q0,r14'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r0'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r0'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r0'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r1'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r1'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r1'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r2'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r2'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r2'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r4'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r4'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r4'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r7'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r7'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r7'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r8'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r8'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r8'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r10'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r10'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r10'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r12'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r12'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r12'
[^:]*:7: Error: syntax error -- `vldrb.s32 q1,r14'
[^:]*:8: Error: syntax error -- `vldrb.u32 q1,r14'
[^:]*:9: Error: syntax error -- `vstrb.32 q1,r14'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r0'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r0'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r0'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r1'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r1'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r1'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r2'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r2'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r2'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r4'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r4'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r4'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r7'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r7'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r7'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r8'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r8'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r8'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r10'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r10'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r10'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r12'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r12'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r12'
[^:]*:7: Error: syntax error -- `vldrb.s32 q2,r14'
[^:]*:8: Error: syntax error -- `vldrb.u32 q2,r14'
[^:]*:9: Error: syntax error -- `vstrb.32 q2,r14'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r0'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r0'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r0'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r1'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r1'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r1'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r2'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r2'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r2'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r4'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r4'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r4'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r7'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r7'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r7'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r8'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r8'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r8'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r10'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r10'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r10'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r12'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r12'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r12'
[^:]*:7: Error: syntax error -- `vldrb.s32 q4,r14'
[^:]*:8: Error: syntax error -- `vldrb.u32 q4,r14'
[^:]*:9: Error: syntax error -- `vstrb.32 q4,r14'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r0'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r0'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r0'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r1'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r1'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r1'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r2'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r2'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r2'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r4'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r4'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r4'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r7'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r7'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r7'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r8'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r8'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r8'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r10'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r10'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r10'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r12'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r12'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r12'
[^:]*:7: Error: syntax error -- `vldrb.s32 q7,r14'
[^:]*:8: Error: syntax error -- `vldrb.u32 q7,r14'
[^:]*:9: Error: syntax error -- `vstrb.32 q7,r14'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r0'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r0'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r0'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r1'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r1'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r1'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r2'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r2'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r2'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r4'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r4'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r4'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r7'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r7'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r7'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r8'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r8'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r8'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r10'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r10'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r10'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r12'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r12'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r12'
[^:]*:17: Error: syntax error -- `vldrh.s16 q0,r14'
[^:]*:18: Error: syntax error -- `vldrh.u16 q0,r14'
[^:]*:19: Error: syntax error -- `vstrh.16 q0,r14'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r0'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r0'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r0'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r1'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r1'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r1'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r2'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r2'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r2'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r4'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r4'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r4'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r7'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r7'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r7'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r8'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r8'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r8'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r10'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r10'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r10'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r12'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r12'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r12'
[^:]*:17: Error: syntax error -- `vldrh.s16 q1,r14'
[^:]*:18: Error: syntax error -- `vldrh.u16 q1,r14'
[^:]*:19: Error: syntax error -- `vstrh.16 q1,r14'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r0'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r0'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r0'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r1'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r1'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r1'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r2'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r2'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r2'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r4'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r4'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r4'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r7'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r7'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r7'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r8'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r8'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r8'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r10'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r10'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r10'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r12'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r12'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r12'
[^:]*:17: Error: syntax error -- `vldrh.s16 q2,r14'
[^:]*:18: Error: syntax error -- `vldrh.u16 q2,r14'
[^:]*:19: Error: syntax error -- `vstrh.16 q2,r14'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r0'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r0'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r0'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r1'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r1'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r1'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r2'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r2'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r2'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r4'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r4'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r4'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r7'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r7'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r7'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r8'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r8'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r8'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r10'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r10'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r10'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r12'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r12'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r12'
[^:]*:17: Error: syntax error -- `vldrh.s16 q4,r14'
[^:]*:18: Error: syntax error -- `vldrh.u16 q4,r14'
[^:]*:19: Error: syntax error -- `vstrh.16 q4,r14'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r0'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r0'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r0'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r1'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r1'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r1'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r2'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r2'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r2'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r4'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r4'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r4'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r7'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r7'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r7'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r8'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r8'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r8'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r10'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r10'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r10'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r12'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r12'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r12'
[^:]*:17: Error: syntax error -- `vldrh.s16 q7,r14'
[^:]*:18: Error: syntax error -- `vldrh.u16 q7,r14'
[^:]*:19: Error: syntax error -- `vstrh.16 q7,r14'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r0'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r0'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r0'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r1'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r1'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r1'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r2'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r2'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r2'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r4'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r4'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r4'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r7'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r7'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r7'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r8'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r8'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r8'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r10'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r10'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r10'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r12'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r12'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r12'
[^:]*:17: Error: syntax error -- `vldrh.s32 q0,r14'
[^:]*:18: Error: syntax error -- `vldrh.u32 q0,r14'
[^:]*:19: Error: syntax error -- `vstrh.32 q0,r14'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r0'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r0'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r0'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r1'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r1'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r1'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r2'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r2'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r2'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r4'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r4'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r4'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r7'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r7'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r7'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r8'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r8'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r8'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r10'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r10'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r10'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r12'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r12'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r12'
[^:]*:17: Error: syntax error -- `vldrh.s32 q1,r14'
[^:]*:18: Error: syntax error -- `vldrh.u32 q1,r14'
[^:]*:19: Error: syntax error -- `vstrh.32 q1,r14'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r0'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r0'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r0'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r1'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r1'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r1'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r2'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r2'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r2'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r4'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r4'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r4'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r7'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r7'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r7'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r8'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r8'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r8'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r10'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r10'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r10'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r12'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r12'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r12'
[^:]*:17: Error: syntax error -- `vldrh.s32 q2,r14'
[^:]*:18: Error: syntax error -- `vldrh.u32 q2,r14'
[^:]*:19: Error: syntax error -- `vstrh.32 q2,r14'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r0'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r0'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r0'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r1'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r1'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r1'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r2'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r2'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r2'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r4'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r4'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r4'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r7'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r7'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r7'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r8'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r8'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r8'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r10'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r10'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r10'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r12'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r12'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r12'
[^:]*:17: Error: syntax error -- `vldrh.s32 q4,r14'
[^:]*:18: Error: syntax error -- `vldrh.u32 q4,r14'
[^:]*:19: Error: syntax error -- `vstrh.32 q4,r14'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r0'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r0'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r0'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r1'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r1'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r1'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r2'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r2'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r2'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r4'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r4'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r4'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r7'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r7'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r7'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r8'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r8'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r8'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r10'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r10'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r10'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r12'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r12'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r12'
[^:]*:17: Error: syntax error -- `vldrh.s32 q7,r14'
[^:]*:18: Error: syntax error -- `vldrh.u32 q7,r14'
[^:]*:19: Error: syntax error -- `vstrh.32 q7,r14'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r0'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r0'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r0'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r1'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r1'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r1'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r2'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r2'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r2'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r4'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r4'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r4'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r7'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r7'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r7'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r8'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r8'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r8'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r10'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r10'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r10'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r12'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r12'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r12'
[^:]*:26: Error: syntax error -- `vldrw.s32 q0,r14'
[^:]*:27: Error: syntax error -- `vldrw.u32 q0,r14'
[^:]*:28: Error: syntax error -- `vstrw.32 q0,r14'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r0'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r0'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r0'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r1'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r1'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r1'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r2'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r2'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r2'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r4'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r4'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r4'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r7'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r7'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r7'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r8'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r8'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r8'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r10'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r10'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r10'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r12'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r12'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r12'
[^:]*:26: Error: syntax error -- `vldrw.s32 q1,r14'
[^:]*:27: Error: syntax error -- `vldrw.u32 q1,r14'
[^:]*:28: Error: syntax error -- `vstrw.32 q1,r14'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r0'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r0'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r0'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r1'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r1'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r1'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r2'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r2'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r2'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r4'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r4'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r4'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r7'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r7'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r7'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r8'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r8'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r8'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r10'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r10'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r10'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r12'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r12'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r12'
[^:]*:26: Error: syntax error -- `vldrw.s32 q2,r14'
[^:]*:27: Error: syntax error -- `vldrw.u32 q2,r14'
[^:]*:28: Error: syntax error -- `vstrw.32 q2,r14'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r0'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r0'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r0'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r1'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r1'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r1'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r2'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r2'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r2'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r4'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r4'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r4'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r7'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r7'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r7'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r8'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r8'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r8'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r10'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r10'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r10'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r12'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r12'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r12'
[^:]*:26: Error: syntax error -- `vldrw.s32 q4,r14'
[^:]*:27: Error: syntax error -- `vldrw.u32 q4,r14'
[^:]*:28: Error: syntax error -- `vstrw.32 q4,r14'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r0'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r0'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r0'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r1'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r1'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r1'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r2'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r2'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r2'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r4'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r4'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r4'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r7'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r7'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r7'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r8'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r8'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r8'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r10'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r10'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r10'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r12'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r12'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r12'
[^:]*:26: Error: syntax error -- `vldrw.s32 q7,r14'
[^:]*:27: Error: syntax error -- `vldrw.u32 q7,r14'
[^:]*:28: Error: syntax error -- `vstrw.32 q7,r14'
