foo:
	mfusr $r0, d0.lo
	mfusr $r0, d0.hi
	mfusr $r0, d1.lo
	mfusr $r0, d1.hi
	mfusr $r0, $pc
	mfusr $r0, $DMA_CFG
	mfusr $r0, $DMA_GCSW
	mfusr $r0, $DMA_CHNSEL
	mfusr $r0, $DMA_ACT
	mfusr $r0, $DMA_SETUP
	mfusr $r0, $DMA_ISADDR
	mfusr $r0, $DMA_ESADDR
	mfusr $r0, $DMA_TCNT
	mfusr $r0, $DMA_STATUS
	mfusr $r0, $DMA_2DSET
	mfusr $r0, $DMA_2DSCTL
	mfusr $r0, $PFMC0
	mfusr $r0, $PFMC1
	mfusr $r0, $PFMC2
	mfusr $r0, $PFM_CTL
