.*: Assembler messages:
.*:5: Warning: .* 0x0*100 truncated to 0x0*0
.*:6: Warning: .* 0x0*101 truncated to 0x0*1
.*:11: Warning: .* 0xf+00 truncated to 0x0*0
.*:12: Warning: .* 0xf+eff truncated to 0x0*ff
.*:17: Error: .* (256|(0x)?100) too large .*
.*:18: Error: .* (257|(0x)?101) too large .*
.*:23: Error: .* (0x)?f+00 too large .*
.*:24: Error: .* (0x)?f+eff too large .*
